@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -86,7 +86,7 @@ static void master_fun(int argc, char* argv[])
     vms[i] = vm;
 
     XBT_INFO("put an actor (%s) on %s", pr_name, vm_name);
-    sg_actor_create(pr_name, (sg_host_t)vm, worker_fun, 0, NULL);
+    sg_actor_create(pr_name, (sg_host_t)vm, &worker_fun, 0, NULL);
 
     xbt_free(vm_name);
     xbt_free(pr_name);
@@ -119,7 +119,7 @@ static void master_fun(int argc, char* argv[])
     char* pr_name = bprintf("WRK%02d", i + 2);
 
     XBT_INFO("put an actor (%s) on %s", pr_name, vm_name);
-    sg_actor_create(pr_name, (sg_host_t)vms[i], worker_fun, 0, NULL);
+    sg_actor_create(pr_name, (sg_host_t)vms[i], &worker_fun, 0, NULL);
 
     free(vm_name);
     free(pr_name);
