@@ -54,9 +54,9 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  e.add_actor("bob", e.host_by_name("bob"), bob);
-  e.add_actor("alice", e.host_by_name("alice"), alice);
-  e.add_actor("carl", e.host_by_name("carl"), carl);
+  e.host_by_name("bob")->add_actor("bob", bob);
+  e.host_by_name("alice")->add_actor("alice", alice);
+  e.host_by_name("carl")->add_actor("carl", carl);
 
   e.run();
 
