@@ -98,15 +98,15 @@ int main(int argc, char** argv)
    * as we do here for the receiver actors. This function can take any kind of parameters, as
    * long as the last parameters of Actor::create() match what your function expects.
    */
-  e.add_actor("receiver", e.host_by_name("Fafard"), &receiver, "mb42");
+  e.host_by_name("Fafard")->add_actor("receiver", &receiver, "mb42");
 
   /* If your actor is getting more complex, you probably want to implement it as a class instead,
    * as we do here for the sender actors. The main behavior goes into operator()() of the class.
    *
    * You can then directly start your actor, as follows: */
-  e.add_actor("sender1", e.host_by_name("Tremblay"), Sender());
+  e.host_by_name("Tremblay")->add_actor("sender1", Sender());
   /* If you want to pass parameters to your class, that's very easy: just use your constructors */
-  e.add_actor("sender2", e.host_by_name("Jupiter"), Sender("GloubiBoulga"));
+  e.host_by_name("Jupiter")->add_actor("sender2", Sender("GloubiBoulga"));
 
   /* But starting actors directly is considered as a bad experimental habit, since it ties the code
    * you want to test with the experimental scenario. Starting your actors from an external deployment
