@@ -63,11 +63,11 @@ int main(int argc, char** argv)
   std::vector<sg4::Host*> list = e.get_all_hosts();
   for (auto const& host : list) {
     /* - Give a unique rank to each host and create a @ref relay_runner actor on each */
-    e.add_actor((std::to_string(id)).c_str(), host, RelayRunner());
+    host->add_actor((std::to_string(id)).c_str(), RelayRunner());
     id++;
   }
   e.run();
-  XBT_INFO("Simulation time %g", sg4::Engine::get_clock());
+  XBT_INFO("Simulation time %g", e.get_clock());
 
   return 0;
 }
