@@ -56,8 +56,8 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  e.add_actor("sender", e.host_by_name("Tremblay"), sender);
-  e.add_actor("receiver", e.host_by_name("Jupiter"), receiver);
+  e.host_by_name("Tremblay")->add_actor("sender", sender);
+   e.host_by_name("Jupiter")->add_actor("receiver",receiver);
 
   e.run();
 
