@@ -90,8 +90,8 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  e.add_actor("sender", e.host_by_name("Tremblay"), sender, 3, 482117300);
-  e.add_actor("receiver", e.host_by_name("Ruby"), receiver);
+  e.host_by_name("Tremblay")->add_actor("sender", sender, 3, 482117300);
+  e.host_by_name("Ruby")->add_actor("receiver", receiver);
 
   e.run();
 
