@@ -71,7 +71,7 @@ int main(int argc, char* argv[])
     vetoed.clear(); // DON'T FORGET TO CLEAR this set between two calls to run
   }
 
-  XBT_INFO("Simulation time %g", sg4::Engine::get_clock());
+  XBT_INFO("Simulation time %g", e.get_clock());
 
   return 0;
 }
