@@ -85,7 +85,7 @@ int main(int argc, char* argv[])
 
   e.run();
 
-  XBT_INFO("Simulated time: %g", sg4::Engine::get_clock());
+  XBT_INFO("Simulated time: %g", e.get_clock());
 
   return 0;
 }
