@@ -173,7 +173,7 @@ int main(int argc, char* argv[])
   xbt_assert(argc == 2, "Usage: %s platform_file\n\tExample: %s ../platforms/energy_platform.xml\n", argv[0], argv[0]);
 
   e.load_platform(argv[1]);
-  e.add_actor("energy_ptask_test", e.host_by_name("MyHost1"), runner);
+  e.host_by_name("MyHost1")->add_actor("energy_ptask_test", runner);
 
   e.run();
   XBT_INFO("End of simulation.");
