@@ -18,8 +18,6 @@ static void executor()
 
 static void dvfs()
 {
-  sg4::Engine& e = *sg4::this_actor::get_engine();
-
   sg4::Host* host1 = sg4::Host::by_name("MyHost1");
   sg4::Host* host2 = sg4::Host::by_name("MyHost2");
   sg4::Host* host3 = sg4::Host::by_name("MyHost3");
@@ -32,16 +30,16 @@ static void dvfs()
   vm_host2->start();
 
   XBT_INFO("Create two activities on Host1: both inside a VM");
-  e.add_actor("p11", vm_host1, executor);
-  e.add_actor("p12", vm_host1, executor);
+  vm_host1->add_actor("p11", executor);
+  vm_host1->add_actor("p12", executor);
 
   XBT_INFO("Create two activities on Host2: one inside a VM, the other directly on the host");
-  e.add_actor("p21", vm_host2, executor);
-  e.add_actor("p22", host2, executor);
+  vm_host2->add_actor("p21",executor);
+  host2->add_actor("p22", executor);
 
   XBT_INFO("Create two activities on Host3: both directly on the host");
-  e.add_actor("p31", host3, executor);
-  e.add_actor("p32", host3, executor);
+  host3->add_actor("p31", executor);
+  host3->add_actor("p32", executor);
 
   XBT_INFO("Wait 5 seconds. The activities are still running (they run for 3 seconds, but 2 activities are co-located, "
            "so they run for 6 seconds)");
@@ -62,13 +60,12 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  e.add_actor("dvfs", e.host_by_name("MyHost1"), dvfs);
+  e.host_by_name("MyHost1")->add_actor("dvfs", dvfs);
 
   e.run();
 
   XBT_INFO("Total simulation time: %.2f; Host2 and Host3 must have the exact same energy consumption; Host1 is "
-           "multi-core and will differ.",
-           sg4::Engine::get_clock());
+           "multi-core and will differ.", e.get_clock());
 
   return 0;
 }
