@@ -55,12 +55,12 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  e.add_actor("dvfs_test", e.host_by_name("MyHost1"), dvfs);
-  e.add_actor("dvfs_test", e.host_by_name("MyHost2"), dvfs);
+  e.host_by_name("MyHost1")->add_actor("dvfs_test", dvfs);
+  e.host_by_name("MyHost2")->add_actor("dvfs_test", dvfs);
 
   e.run();
 
-  XBT_INFO("Total simulation time: %e", sg4::Engine::get_clock());
+  XBT_INFO("Total simulation time: %e", e.get_clock());
 
   return 0;
 }
