@@ -60,7 +60,7 @@ int main(int argc, char* argv[])
 {
   sg4::Engine e(&argc, argv);
   e.load_platform(argv[1]);
-  e.add_actor("worker", e.host_by_name("Tremblay"), worker);
+  e.host_by_name("Tremblay")->add_actor("worker", worker);
   e.run();
 
   return 0;
