@@ -57,7 +57,7 @@ static void maestro(void* /* data */)
   sg4::Engine& e = *sg4::this_actor::get_engine();
 
   ensure_other_tid();
-  e.add_actor("receiver", sg4::Host::by_name("Jupiter"), receiver);
+  e.host_by_name("Jupiter")->add_actor("receiver", receiver);
   e.run();
 }
 
