@@ -37,15 +37,14 @@ static void go(sg4::ConditionVariablePtr cv, sg4::MutexPtr mtx, std::shared_ptr<
 
 static void main_actor()
 {
-  sg4::Engine& e = *simgrid::s4u::this_actor::get_engine();
   auto mtx   = sg4::Mutex::create();
   auto cv    = sg4::ConditionVariable::create();
   auto ready = std::make_shared<bool>(false);
 
   auto* host = sg4::this_actor::get_host();
   for (int i = 0; i < 10; ++i)
-    e.add_actor("competitor", host, competitor, i, cv, mtx, ready);
-  e.add_actor("go", host, go, cv, mtx, ready);
+    host->add_actor("competitor", competitor, i, cv, mtx, ready);
+  host->add_actor("go", go, cv, mtx, ready);
 }
 
 int main(int argc, char* argv[])
@@ -53,7 +52,7 @@ int main(int argc, char* argv[])
   sg4::Engine e(&argc, argv);
   e.load_platform("../../platforms/small_platform.xml");
 
-  e.add_actor("main", e.host_by_name("Tremblay"), main_actor);
+  e.host_by_name("Tremblay")->add_actor("main", main_actor);
 
   e.run();
   return 0;
