@@ -129,7 +129,7 @@ int main(int argc, char* argv[])
     t->set_parallelism_degree(10);
 
   // Create the actor that will inject requests during the simulation
-  e.add_actor("request_sender", pm0, request_sender, nginx_web_server, 500);
+  pm0->add_actor("request_sender", request_sender, nginx_web_server, 500);
 
   // Add a function to be called when tasks end for log purpose
   int requests_processed = 0;
