@@ -37,9 +37,12 @@ public class actor_daemon {
     Engine e = new Engine(args);
 
     e.load_platform(args[0]);
-    e.add_actor("worker", e.host_by_name("Boivin"), new worker());
-    e.add_actor("daemon", e.host_by_name("Tremblay"), new my_daemon());
+    e.host_by_name("Boivin").add_actor("worker", new worker());
+    e.host_by_name("Tremblay").add_actor("daemon", new my_daemon());
 
     e.run();
+
+    // The following call is useless in your code, but our continuous integration uses it to track memleaks
+    e.force_garbage_collection();
   }
 }
