@@ -15,13 +15,13 @@ import org.simgrid.s4u.*;
  */
 
 class Yielder extends Actor {
-  long number_of_yields;
-  public Yielder(long number_of_yields) { this.number_of_yields = number_of_yields; }
+  long numberOfYields;
+  public Yielder(long numberOfYields) { this.numberOfYields = numberOfYields; }
   public void run()
   {
-    for (int i = 0; i < number_of_yields; i++)
+    for (int i = 0; i < numberOfYields; i++)
       this.yield();
-    Engine.info("I yielded %d times. Goodbye now!", number_of_yields);
+    Engine.info("I yielded %d times. Goodbye now!", numberOfYields);
   }
 }
 
@@ -31,9 +31,12 @@ public class actor_yield {
     Engine e = new Engine(args);
     e.load_platform(args[0]);
 
-    e.add_actor("yielder", e.host_by_name("Tremblay"), new Yielder(10));
-    e.add_actor("yielder", e.host_by_name("Ruby"), new Yielder(15));
+    e.host_by_name("Tremblay").add_actor("yielder", new Yielder(10));
+    e.host_by_name("Ruby").add_actor("yielder", new Yielder(15));
 
     e.run(); /* - Run the simulation */
+
+    // The following call is useless in your code, but our continuous integration uses it to track memleaks
+    e.force_garbage_collection();
   }
 }
\ No newline at end of file
