@@ -30,5 +30,8 @@ public class dag_from_json_simple {
     });
 
     e.run();
+
+    // The following call is useless in your code, but our continuous integration uses it to track memleaks
+    e.force_garbage_collection();
   }
 }
\ No newline at end of file
