@@ -29,10 +29,13 @@ public class exec_unassigned {
     Engine e = new Engine(args);
     e.load_platform(args[0]);
 
-    e.add_actor("worker", e.host_by_name("Fafard"), new worker());
+    e.host_by_name("Fafard").add_actor("worker", new worker());
 
     e.run();
 
     Engine.info("Simulation ends.");
+
+    // The following call is useless in your code, but our continuous integration uses it to track memleaks
+    e.force_garbage_collection();
   }
 }
