@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -18,39 +18,38 @@ namespace sg4 = simgrid::s4u;
  * @param radicals IDs of nodes inside the cabinet
  * @return netzone the created netzone
  */
-static sg4::NetZone*
-create_cabinet(const sg4::NetZone* root, const std::string& name, const std::vector<int>& radicals)
+static sg4::NetZone* create_cabinet(sg4::NetZone* root, const std::string& name, const std::vector<int>& radicals)
 {
-  auto* cluster      = sg4::create_star_zone(name)->set_parent(root);
+  auto* cluster      = root->add_netzone_star(name);
   std::string prefix = "griffon-";
   std::string suffix = ".nancy.grid5000.fr";
 
   /* create the backbone link */
-  const sg4::Link* l_bb = cluster->create_link("backbone-" + name, "1.25GBps");
+  const sg4::Link* l_bb = cluster->add_link("backbone-" + name, "1.25GBps");
   sg4::LinkInRoute backbone(l_bb);
 
   /* create all hosts and connect them to outside world */
   for (const auto& id : radicals) {
     std::string hostname = prefix + std::to_string(id) + suffix;
     /* create host */
-    const sg4::Host* host = cluster->create_host(hostname, "286.087kf");
+    const sg4::Host* host = cluster->add_host(hostname, "286.087kf");
     /* create UP/DOWN link */
-    const sg4::Link* link = cluster->create_split_duplex_link(hostname, "125MBps")->set_latency("24us");
+    const sg4::Link* link = cluster->add_split_duplex_link(hostname, "125MBps")->set_latency("24us");
 
     /* add link and backbone for communications from the host */
     cluster->add_route(host, nullptr, {{link, sg4::LinkInRoute::Direction::UP}, backbone}, true);
   }
 
   /* create gateway */
-  cluster->set_gateway(cluster->create_router(prefix + name + "-router" + suffix));
+  cluster->set_gateway(cluster->add_router(prefix + name + "-router" + suffix));
 
   cluster->seal();
   return cluster;
 }
 
 /** @brief Programmatic version of griffon.xml */
-extern "C" void load_platform(const sg4::Engine& e);
-void load_platform(const sg4::Engine& /*e*/)
+extern "C" void load_platform(sg4::Engine& e);
+void load_platform(sg4::Engine& e)
 {
   /**
    * C++ version of griffon.xml
@@ -71,11 +70,10 @@ void load_platform(const sg4::Engine& /*e*/)
    * host1     ...      hostN      host1      ...      hostM      host1      ...       hostQ
    */
 
-  auto* root = sg4::create_star_zone("AS_griffon");
-  sg4::NetZone* cab_zone;
+  auto* root = e.get_netzone_root()->add_netzone_star("AS_griffon");
 
   /* create top link */
-  const sg4::Link* l_bb = root->create_link("backbone", "1.25GBps")->set_latency("24us")->seal();
+  const sg4::Link* l_bb = root->add_link("backbone", "1.25GBps")->set_latency("24us")->seal();
   sg4::LinkInRoute backbone{l_bb};
 
   /* create cabinet1 */
@@ -84,7 +82,7 @@ void load_platform(const sg4::Engine& /*e*/)
   rad[rad.size() - 1]  = 60;
   rad[rad.size() - 2]  = 59;
   rad[rad.size() - 3]  = 58;
-  cab_zone             = create_cabinet(root, "cabinet1", rad);
+  const sg4::NetZone* cab_zone = create_cabinet(root, "cabinet1", rad);
   root->add_route(cab_zone, nullptr, {backbone});
 
   /* create cabinet2 */
