@@ -52,7 +52,7 @@ if __name__ == '__main__':
   # Load the platform description
   e.load_platform(sys.argv[1])
 
-  e.add_actor("bob",   Host.by_name("bob"), bob)
-  e.add_actor("alice", Host.by_name("alice"), alice)
+  Host.by_name("bob").add_actor("bob", bob)
+  Host.by_name("alice").add_actor("alice", alice)
 
   e.run()
