@@ -1,6 +1,6 @@
 /* Public interface to the Barrier datatype                                 */
 
-/* Copyright (c) 2018-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2018-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -11,7 +11,10 @@
 #include <simgrid/forward.h>
 
 #ifdef __cplusplus
-constexpr bool SG_BARRIER_SERIAL_THREAD = true;
+extern "C++"
+{
+  constexpr bool SG_BARRIER_SERIAL_THREAD = true;
+}
 #else
 #define SG_BARRIER_SERIAL_THREAD -1
 #endif
