@@ -22,15 +22,6 @@ XBT_PUBLIC sg_error_t sg_comm_wait(sg_comm_t comm);
 XBT_PUBLIC sg_error_t sg_comm_wait_for(sg_comm_t comm, double timeout);
 XBT_PUBLIC void sg_comm_unref(sg_comm_t comm);
 
-#ifndef DOXYGEN
-XBT_ATTRIB_DEPRECATED_v401("Please use sg_activity_set_t instead") XBT_PUBLIC
-    void sg_comm_wait_all(sg_comm_t* comms, size_t count);
-XBT_ATTRIB_DEPRECATED_v401("Please use sg_activity_set_t instead") XBT_PUBLIC
-    ssize_t sg_comm_wait_any_for(sg_comm_t* comms, size_t count, double timeout);
-XBT_ATTRIB_DEPRECATED_v401("Please use sg_activity_set_t instead") XBT_PUBLIC
-    ssize_t sg_comm_wait_any(sg_comm_t* comms, size_t count);
-#endif
-
 SG_END_DECL
 
 #endif /* INCLUDE_SIMGRID_COMM_H_ */
