@@ -35,6 +35,8 @@ public:
   const char* get_cname() const { return name_.c_str(); }
   /** @brief the NetZone in which this NetPoint is included */
   NetZoneImpl* get_englobing_zone() const { return englobing_zone_; }
+  /** @brief Returns the NetZones that contain the NetPoint, from root to leaf */
+  std::vector<NetZoneImpl*> get_all_englobing_zones() const;
   /** @brief Set the NetZone in which this NetPoint is included */
   NetPoint* set_englobing_zone(NetZoneImpl* netzone_p);
   NetPoint* set_coordinates(const std::string& coords);
