@@ -133,7 +133,7 @@ protected:
   friend kernel::resource::StandardLinkImpl;
   void netpoint_register(simgrid::kernel::routing::NetPoint* card);
   void netpoint_unregister(simgrid::kernel::routing::NetPoint* card);
-  XBT_ATTRIB_DEPRECATED_v401("The root netzone was already created for you. Please use one of the "
+  XBT_ATTRIB_DEPRECATED_v403("The root netzone was already created for you. Please use one of the "
                              "Netzone::add_netzone_*() method instead") void set_netzone_root(const NetZone* netzone);
 #endif /*DOXYGEN*/
 
@@ -168,6 +168,8 @@ public:
   size_t get_actor_count() const;
   aid_t get_actor_max_pid() const;
   std::vector<ActorPtr> get_all_actors() const;
+  /* Display the status of all actors on the standard error stream */
+  void display_all_actors_status() const;
   std::vector<ActorPtr> get_filtered_actors(const std::function<bool(ActorPtr)>& filter) const;
 
   std::vector<kernel::routing::NetPoint*> get_all_netpoints() const;
@@ -210,17 +212,22 @@ public:
   /** Create an actor from a @c std::function<void()>.
    *  If the actor is restarted, it gets a fresh copy of the function.
    *  @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
+  XBT_ATTRIB_DEPRECATED_v403("Please use Host::add_actor.")
   static ActorPtr add_actor(const std::string& name, s4u::Host* host, const std::function<void()>& code);
 
   /** Add an actor taking a vector of strings as parameters.
    *  @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
+  XBT_ATTRIB_DEPRECATED_v403("Please use Host::add_actor.")
   ActorPtr add_actor(const std::string& name, s4u::Host* host, const std::string& function,
                      std::vector<std::string> args);
   /** Create an actor from a callable thing.
    *  @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
-  template <class F> ActorPtr add_actor(const std::string& name, s4u::Host* host, F code)
+  
+  template <class F> 
+  XBT_ATTRIB_DEPRECATED_v403("Please use Host::add_actor.")
+  ActorPtr add_actor(const std::string& name, s4u::Host* host, F code)
   {
-    return add_actor(name, host, std::function<void()>(std::move(code)));
+    return host->add_actor(name, std::function<void()>(std::move(code)));
   }
 
   /** Create an actor using a callable thing and its arguments.
@@ -228,14 +235,15 @@ public:
    * Note that the arguments will be copied, so move-only parameters are forbidden.
    * @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
   template <class F, class... Args // This constructor is enabled only if calling code(args...) is valid
-#ifndef DOXYGEN /* breathe seem to choke on function signatures in template parameter, see breathe#611 */
-            ,
-            typename = typename std::invoke_result_t<F, Args...>
-#endif
-            >
+  #ifndef DOXYGEN /* breathe seem to choke on function signatures in template parameter, see breathe#611 */
+  ,
+  typename = typename std::invoke_result_t<F, Args...>
+  #endif
+  >
+  XBT_ATTRIB_DEPRECATED_v403("Please use Host::add_actor.")
   ActorPtr add_actor(const std::string& name, s4u::Host* host, F code, Args... args)
   {
-    return add_actor(name, host, std::bind(std::move(code), std::move(args)...));
+    return host->add_actor(name, std::bind(std::move(code), std::move(args)...));
   }
 
   kernel::EngineImpl* get_impl() const { return pimpl_; }
@@ -262,9 +270,6 @@ public:
 
   /** Add a callback fired when the platform is created (ie, the xml file parsed). */
   static void on_platform_created_cb(const std::function<void()>& cb) { on_platform_created.connect(cb); }
-  /** Add a callback fired when the platform is sealed and cannot be further modified, right before the actual
-   *  simulation starts. */
-  static void on_platform_sealed_cb(const std::function<void()>& cb) { on_platform_sealed.connect(cb); }
   /** Add a callback fired when the platform is about to be created
    * (ie, after any configuration change and just before the resource creation) */
   static void on_platform_creation_cb(const std::function<void()>& cb) { on_platform_creation.connect(cb); }
@@ -287,7 +292,6 @@ public:
   /* FIXME signals should be private */
   static xbt::signal<void()> on_platform_creation;
   static xbt::signal<void()> on_platform_created;
-  static xbt::signal<void()> on_platform_sealed;
 #endif
 
 private:
