@@ -130,12 +130,6 @@ public:
    */
   Host* set_cpu_factor_cb(const std::function<double(Host&, double)>& cb);
 
-#ifndef DOXYGEN
-  using CpuFactorCb = double(double flops);
-  XBT_ATTRIB_DEPRECATED_v401("Please use set_cpu_factor_cb() instead") Host* set_factor_cb(
-      const std::function<CpuFactorCb>& cb);
-#endif
-
   size_t get_actor_count() const;
   std::vector<ActorPtr> get_all_actors() const;
 
@@ -245,14 +239,45 @@ public:
   Host* set_pstate(unsigned long pstate_index);
   Host* set_coordinates(const std::string& coords);
 
+  /** Create an actor from a @c std::function<void()>.
+   *  If the actor is restarted, it gets a fresh copy of the function.
+   *  @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
+  ActorPtr add_actor(const std::string& name, const std::function<void()>& code);
+
+  /** Add an actor taking a vector of strings as parameters.
+   *  @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
+  ActorPtr add_actor(const std::string& name, const std::string& function,
+                     std::vector<std::string> args);
+  /** Create an actor from a callable thing.
+   *  @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
+  template <class F> ActorPtr add_actor(const std::string& name, F code)
+  {
+    return add_actor(name, std::function<void()>(std::move(code)));
+  }
+
+  /** Create an actor using a callable thing and its arguments.
+   *
+   * Note that the arguments will be copied, so move-only parameters are forbidden.
+   * @verbatim embed:rst:inline See the :ref:`example <s4u_ex_actors_create>`. @endverbatim */
+  template <class F, class... Args // This constructor is enabled only if calling code(args...) is valid
+#ifndef DOXYGEN /* breathe seem to choke on function signatures in template parameter, see breathe#611 */
+            ,
+            typename = typename std::invoke_result_t<F, Args...>
+#endif
+            >
+  ActorPtr add_actor(const std::string& name, F code, Args... args)
+  {
+    return add_actor(name, std::bind(std::move(code), std::move(args)...));
+  }
+
   std::vector<Disk*> get_disks() const;
   Disk* get_disk_by_name(const std::string& name) const;
 
   #ifndef DOXYGEN
-   XBT_ATTRIB_DEPRECATED_v401("Please use Host::add_disk")
+   XBT_ATTRIB_DEPRECATED_v403("Please use Host::add_disk")
    Disk* create_disk(const std::string& name, double read_bandwidth, double write_bandwidth)
    { return add_disk(name, read_bandwidth, write_bandwidth); }
-   XBT_ATTRIB_DEPRECATED_v401("Please use Host::add_disk")
+   XBT_ATTRIB_DEPRECATED_v403("Please use Host::add_disk")
    Disk* create_disk(const std::string& name, const std::string& read_bandwidth, const std::string& write_bandwidth)
    { return add_disk(name, read_bandwidth, write_bandwidth); }
   #endif 
