@@ -37,7 +37,10 @@ class XBT_PUBLIC Link : public xbt::Extendable<Link> {
 
 protected:
   // Links are created from the NetZone, and destroyed by their private implementation when the simulation ends
-  explicit Link(kernel::resource::LinkImpl* pimpl) : pimpl_(pimpl) {}
+  explicit Link(kernel::resource::LinkImpl* pimpl) : pimpl_(pimpl)
+  {
+    s4u::Link::on_creation(*this); // notify the signal
+  }
   virtual ~Link() = default;
   // The implementation that never changes
   kernel::resource::LinkImpl* const pimpl_;
@@ -68,6 +71,9 @@ public:
   static Link* by_name(const std::string& name);
   static Link* by_name_or_null(const std::string& name);
 
+  /** @brief Returns the networking zone englobing that host */
+  NetZone* get_englobing_zone() const;
+
   /** @brief Retrieves the name of that link as a C++ string */
   const std::string& get_name() const;
   /** @brief Retrieves the name of that link as a C string */
