@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -1247,8 +1247,32 @@ XBT_PUBLIC void SMPI_thread_create();
 SG_END_DECL
 
 #ifdef __cplusplus
+/* Special public functions for mpi-benchmarks */
+XBT_PUBLIC void SMPI_executable_start(const std::string& executable, const std::vector<simgrid::s4u::Host*>& hosts,
+                                      const std::vector<std::string> run_args);
+
 XBT_PUBLIC void SMPI_app_instance_start(const char* name, std::function<void()> const& code,
                                         std::vector<simgrid::s4u::Host*> const& hosts);
+
+template <class F>
+XBT_PUBLIC void SMPI_app_instance_start(const char* name, F code, std::vector<simgrid::s4u::Host*> const& hosts)
+{
+  SMPI_app_instance_start(name, std::function<void()>(std::move(code)), hosts);
+}
+
+#if __cplusplus >= 201703L
+template <class F, class... Args, // This constructor is enabled only if calling code(args...) is valid
+#ifndef DOXYGEN /* breathe seem to choke on function signatures in template parameter, see breathe#611 */
+          typename = typename std::invoke_result_t<F, Args...>
+#endif
+          >
+XBT_PUBLIC void SMPI_app_instance_start(const char* name, F code, std::vector<simgrid::s4u::Host*> const& hosts,
+                                        Args... args)
+{
+  SMPI_app_instance_start(name, std::bind(std::move(code), std::move(args)...), hosts);
+}
+#endif
+
 XBT_PUBLIC void SMPI_app_instance_join(const std::string& instance_id);
 
 /* This version without parameter is nice to use with SMPI_app_instance_start() */
