@@ -1,7 +1,6 @@
 /* xbt.h - Public interface to the xbt (SimGrid's toolbox)                  */
 
-/* Copyright (c) 2004-2023. The SimGrid Team.
- * All rights reserved.                                                     */
+/* Copyright (c) 2004-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -22,7 +21,10 @@
 
 #include <xbt/config.h>
 #ifdef __cplusplus
+extern "C++"
+{
 #include <xbt/config.hpp>
+}
 #endif
 
 #include <xbt/xbt_os_time.h>
