@@ -6,7 +6,10 @@
 #ifndef INSTR_PAJE_TYPES_HPP
 #define INSTR_PAJE_TYPES_HPP
 
+#include "src/instr/instr_paje_containers.hpp"
+#include "src/instr/instr_paje_events.hpp"
 #include "src/instr/instr_private.hpp"
+
 #include <memory>
 #include <string>
 #include <vector>
@@ -85,6 +88,25 @@ public:
   void sub_event(double timestamp, double value);
 };
 
+class EntityValue {
+  long long int id_ = new_paje_id();
+  std::string name_;
+  std::string color_;
+  Type* parent_;
+
+  static xbt::signal<void(const EntityValue&)> on_creation;
+
+public:
+  static void on_creation_cb(const std::function<void(const EntityValue&)>& cb) { on_creation.connect(cb); }
+  explicit EntityValue(const std::string& name, const std::string& color, Type* parent);
+
+  long long int get_id() const { return id_; }
+  std::string get_name() const { return name_; }
+  const char* get_cname() const { return name_.c_str(); }
+  std::string get_color() const { return color_; }
+  Type* get_parent() const { return parent_; }
+};
+
 class ValueType : public Type {
 public:
   std::map<std::string, EntityValue, std::less<>> values_;
