@@ -52,9 +52,6 @@ constexpr std::initializer_list<std::pair<const char*, context::ContextFactory*
 #if HAVE_RAW_CONTEXTS
     {"raw", &context::raw_factory},
 #endif
-#if HAVE_UCONTEXT_CONTEXTS
-    {"ucontext", &context::sysv_factory},
-#endif
 #if HAVE_BOOST_CONTEXTS
     {"boost", &context::boost_factory},
 #endif
@@ -259,11 +256,6 @@ void EngineImpl::context_mod_init() const
 #else
     XBT_ERROR("  (raw contexts were disabled at compilation time on this machine -- check configure logs for details)");
 #endif
-#if HAVE_UCONTEXT_CONTEXTS
-    XBT_ERROR("  ucontext: classical system V contexts (implemented with makecontext, swapcontext and friends)");
-#else
-    XBT_ERROR("  (ucontext was disabled at compilation time on this machine -- check configure logs for details)");
-#endif
 #if HAVE_BOOST_CONTEXTS
     XBT_ERROR("  boost: this uses the boost libraries context implementation");
 #else
@@ -321,9 +313,6 @@ void EngineImpl::seal_platform() const
 
   /* seal netzone root, recursively seal children netzones, hosts and disks */
   netzone_root_->seal();
-
-  // Now the platform is officially sealed and thus completely created
-  simgrid::s4u::Engine::on_platform_sealed();
 }
 
 void EngineImpl::load_platform(const std::string& platf)
