@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -76,6 +76,16 @@ IoImpl& IoImpl::set_dst_host(s4u::Host* host)
 
 IoImpl* IoImpl::start()
 {
+  if (is_detached()) {
+    //ownership has been transferred to maestro
+    // remove this activity from the list of the actor that created it
+    get_actor()->activities_.erase(this);
+    // set maestro as the new actor for this activity
+    set_actor(EngineImpl::get_instance()->get_maestro());
+    // Add a ref on the interface in case the initial ends before the completion of the detached activity
+    piface_->add_ref();
+  }
+
   set_state(State::RUNNING);
   if (dst_host_ == nullptr) {
     XBT_DEBUG("Starting regular I/O");
@@ -95,32 +105,6 @@ IoImpl* IoImpl::start()
   return this;
 }
 
-void IoImpl::set_exception(actor::ActorImpl* issuer)
-{
-  switch (get_state()) {
-    case State::FAILED:
-      issuer->set_wannadie();
-      static_cast<s4u::Io*>(get_iface())->complete(s4u::Activity::State::FAILED);
-      issuer->exception_ = std::make_exception_ptr(StorageFailureException(XBT_THROW_POINT, "Storage failed"));
-      break;
-    case State::CANCELED:
-      issuer->exception_ = std::make_exception_ptr(CancelException(XBT_THROW_POINT, "I/O Canceled"));
-      break;
-    case State::SRC_HOST_FAILURE:
-    case State::DST_HOST_FAILURE:
-       issuer->set_wannadie();
-       static_cast<s4u::Io*>(get_iface())->complete(s4u::Activity::State::FAILED);
-       issuer->exception_ = std::make_exception_ptr(StorageFailureException(XBT_THROW_POINT, "Host failed"));
-      break;
-    case State::TIMEOUT:
-      issuer->exception_ = std::make_exception_ptr(TimeoutException(XBT_THROW_POINT, "Timeouted"));
-      break;
-    default:
-      xbt_assert(get_state() == State::DONE, "Internal error in IoImpl::finish(): unexpected synchro state %s",
-                 get_state_str());
-  }
-}
-
 void IoImpl::finish()
 {
   XBT_DEBUG("IoImpl::finish() in state %s", get_state_str());
@@ -132,9 +116,11 @@ void IoImpl::finish()
           set_state(State::SRC_HOST_FAILURE);
         else if (not dst_host_->is_on())
           set_state(State::DST_HOST_FAILURE);
-      } else if ((disk_ && not disk_->is_on()) || (dst_disk_ && not dst_disk_->is_on()))
+      }
+      if ((disk_ && not disk_->is_on()) || (dst_disk_ && not dst_disk_->is_on())) {
         set_state(State::FAILED);
-      else
+        static_cast<s4u::Io*>(get_iface())->complete(s4u::Activity::State::FAILED);
+      } else
         set_state(State::CANCELED);
     } else {
       set_state(State::DONE);
@@ -143,29 +129,41 @@ void IoImpl::finish()
     clean_action();
   }
 
+  if (detached_) {
+    // Remove the finishing activity from maestro's list
+    EngineImpl::get_instance()->get_maestro()->activities_.erase(this);
+    // release the extra ref taken at start time
+    piface_->unref();
+  }
+
   while (not simcalls_.empty()) {
-    actor::Simcall* simcall = simcalls_.front();
-    simcalls_.pop_front();
+    auto issuer = unregister_first_simcall();
+    if (issuer == nullptr) /* don't answer exiting and dying actors */
+      continue;
 
-    /* If a waitany simcall is waiting for this synchro to finish, then remove it from the other synchros in the waitany
-     * list. Afterwards, get the position of the actual synchro in the waitany list and return it as the result of the
-     * simcall */
+    issuer->activities_.erase(this);
 
-    if (simcall->call_ == actor::Simcall::Type::NONE) // FIXME: maybe a better way to handle this case
-      continue;                                       // if process handling comm is killed
-
-    handle_activity_waitany(simcall);
-
-    if (not simcall->issuer_->get_host()->is_on()) {
-      simcall->issuer_->set_wannadie();
-    } else {
-      // Do not answer to dying actors
-      if (not simcall->issuer_->wannadie()) {
-        set_exception(simcall->issuer_);
-        simcall->issuer_->waiting_synchro_ = nullptr;
-        simcall->issuer_->simcall_answer();
-      }
+    switch (get_state()) {
+      case State::FAILED:
+        issuer->set_wannadie();
+        static_cast<s4u::Io*>(get_iface())->complete(s4u::Activity::State::FAILED);
+        issuer->exception_ = std::make_exception_ptr(StorageFailureException(XBT_THROW_POINT, "Storage failed"));
+        break;
+      case State::CANCELED:
+        issuer->exception_ = std::make_exception_ptr(CancelException(XBT_THROW_POINT, "I/O Canceled"));
+        break;
+      case State::SRC_HOST_FAILURE:
+      case State::DST_HOST_FAILURE:
+        issuer->set_wannadie();
+        static_cast<s4u::Io*>(get_iface())->complete(s4u::Activity::State::FAILED);
+        issuer->exception_ = std::make_exception_ptr(StorageFailureException(XBT_THROW_POINT, "Host failed"));
+        break;
+      default:
+        xbt_assert(get_state() == State::DONE, "Internal error in IoImpl::finish(): unexpected synchro state %s",
+                   get_state_str());
     }
+
+    issuer->simcall_answer();
   }
 }
 
