@@ -1,11 +1,14 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/kernel/activity/MutexImpl.hpp"
-#include "src/kernel/activity/Synchro.hpp"
+#include "src/kernel/actor/SynchroObserver.hpp"
+#include "src/kernel/resource/CpuImpl.hpp"
 
+XBT_LOG_NEW_SUBCATEGORY(ker_synchro, kernel,
+                        "Kernel synchronization activities (lock/acquire on a mutex, semaphore or condition)");
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_mutex, ker_synchro, "Mutex kernel-space implementation");
 
 namespace simgrid::kernel::activity {
@@ -26,19 +29,17 @@ void MutexAcquisitionImpl::wait_for(actor::ActorImpl* issuer, double timeout)
 
   if (mutex_->get_owner() == issuer_) { // I'm the owner
     finish();
-  } else {
-    // Already in the queue
   }
+
+  // Already in the queue
 }
 
 void MutexAcquisitionImpl::finish()
 {
   xbt_assert(simcalls_.size() == 1, "Unexpected number of simcalls waiting: %zu", simcalls_.size());
-  actor::Simcall* simcall = simcalls_.front();
-  simcalls_.pop_front();
-
-  simcall->issuer_->waiting_synchro_ = nullptr;
-  simcall->issuer_->simcall_answer();
+  auto issuer = unregister_first_simcall();
+  if (issuer != nullptr) /* don't answer exiting and dying actors */
+    issuer->simcall_answer();
 }
 
 /* -------- Mutex -------- */
@@ -47,6 +48,8 @@ unsigned MutexImpl::next_id_ = 0;
 
 MutexAcquisitionImplPtr MutexImpl::lock_async(actor::ActorImpl* issuer)
 {
+  XBT_DEBUG("lock async of mutex %p %u", this, id_);
+
   /* If the mutex is recursive */
   if (is_recursive_) {
     if (owner_ == issuer) {
@@ -107,14 +110,18 @@ bool MutexImpl::try_lock(actor::ActorImpl* issuer)
 /** Unlock a mutex for a actor
  *
  * Unlocks the mutex and gives it to a actor waiting for it.
- * If the unlocker is not the owner of the mutex nothing happens.
+ * If the unlocker is not the owner of the mutex, the attempt results in an assertion failure.
  * If there are no actor waiting, it sets the mutex as free.
  */
 void MutexImpl::unlock(actor::ActorImpl* issuer)
 {
   XBT_IN("(%p, %p)", this, issuer);
-  xbt_assert(issuer == owner_, "Cannot release that mutex: you're not the owner. %s is (pid:%ld).",
-             owner_ != nullptr ? owner_->get_cname() : "(nobody)", owner_ != nullptr ? owner_->get_pid() : -1);
+  xbt_assert(
+      issuer == owner_,
+      "Cannot release that mutex: you're not the owner. %s is (pid:%ld). "
+      "According to specification of https://pubs.opengroup.org/onlinepubs/009695399/functions/pthread_mutex_lock.html "
+      "this is an undefined behavior.",
+      owner_ != nullptr ? owner_->get_cname() : "(nobody)", owner_ != nullptr ? owner_->get_pid() : -1);
 
   if (is_recursive_) {
     recursive_depth--;
@@ -130,7 +137,10 @@ void MutexImpl::unlock(actor::ActorImpl* issuer)
     owner_ = acq->get_issuer();
     acq->grant();
     recursive_depth = acq->recursive_depth_;
-    if (acq == owner_->waiting_synchro_)
+
+    // Finish the acquisition if the owner is already blocked on its completion
+    auto& synchros = owner_->waiting_synchros_;
+    if (std::find(synchros.begin(), synchros.end(), acq) != synchros.end())
       acq->finish();
     // else, the issuer is not blocked on this acquisition so no need to release it
 
