@@ -104,6 +104,7 @@ public:
   std::exception_ptr exception_;
   bool suspended_ = false;
 
+  activity::MemoryAccessImplPtr recorded_memory_accesses_;
   /* the activities on which the actor is currently blocked with a wait(). There is more than one e.g. in a wait_any() */
   std::vector<activity::ActivityImplPtr> waiting_synchros_; 
   /* the activities linked to that actor. They are canceled when it dies, suspend/resumed when it is */
@@ -144,6 +145,8 @@ public:
     }
   }
 
+  simgrid::kernel::activity::MemoryAccessImpl* get_memory_access() { return recorded_memory_accesses_.get(); }
+
   /* S4U/implem interfaces */
 private:
   s4u::Actor piface_; // Our interface is part of ourselves
