@@ -1,10 +1,10 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#ifndef SIMGRID_SIMCALL_HPP
-#define SIMGRID_SIMCALL_HPP
+#ifndef SIMGRID_KERNEL_ACTOR_SIMCALL_HPP
+#define SIMGRID_KERNEL_ACTOR_SIMCALL_HPP
 
 #include "simgrid/forward.h"
 #include "xbt/utility.hpp"
@@ -14,7 +14,7 @@ namespace simgrid::kernel::actor {
 /** Contains what's needed to run some code in kernel mode on behalf of an actor */
 class Simcall {
 public:
-  /** All possible simcalls. */
+  /** All possible simcall kinds. */
   XBT_DECLARE_ENUM_CLASS(Type, NONE, RUN_ANSWERED, RUN_BLOCKING);
 
   Type call_                                         = Type::NONE;
