@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -11,12 +11,15 @@
 #include "src/kernel/context/Context.hpp"
 #include "src/sthread/sthread.h"
 
+#include <thread>
 #include <vector>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(ker_context, kernel, "Context switching mechanism");
 
 namespace simgrid::kernel::context {
 
+std::function<ContextFactory*(void)> ContextFactory::initializer;
+
 void Context::set_nthreads(int nb_threads)
 {
   if (nb_threads <= 0) {
