@@ -9,6 +9,7 @@
 #include "simgrid/kernel/resource/Action.hpp"
 #include "simgrid/kernel/resource/Model.hpp"
 #include "xbt/asserts.h"
+#include "xbt/backtrace.hpp"
 #include "xbt/mallocator.h"
 
 #include <boost/intrusive/list.hpp>
@@ -395,6 +396,8 @@ public:
   unsigned visited_; /* used by System::update_modified_cnst_set() */
   double mu_;
 
+  xbt::Backtrace* backtrace_ = nullptr; // Used to debug leaking variables when cfg debug/lmm-leak:ON
+
 private:
   static int next_rank_; // To give a separate rank_ to each variable
 };
