@@ -126,10 +126,6 @@ public:
    * Implemented only for cas01
    */
   virtual void set_cpu_factor_cb(const std::function<double(s4u::Host&, double)>& cb) { THROW_UNIMPLEMENTED; }
-  virtual void set_factor_cb(const std::function<s4u::Host::CpuFactorCb>& cb)
-  {
-    THROW_UNIMPLEMENTED;
-  } // XBT_ATTRIB_DEPRECATED_v401
 
   /**
    * @brief Execute some quantity of computation
