@@ -1,4 +1,4 @@
-/* Copyright (c) 2019-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2019-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -112,6 +112,9 @@ public:
   void turn_on() override;
   void turn_off() override;
 
+  void on_read_bandwidth_change() const;
+  void on_write_bandwidth_change() const;
+
   void seal() override;
   void destroy(); // Must be called instead of the destructor
 
