@@ -10,14 +10,23 @@
 #include "src/kernel/resource/Resource.hpp"
 #include "xbt/PropertyHolder.hpp"
 
+#include <string>
+
 namespace simgrid::kernel::resource {
 
 /************
  * Resource *
  ************/
 class LinkImpl : public Resource_T<LinkImpl>, public xbt::PropertyHolder {
+  s4u::Link::SharingPolicy sharing_policy_;
+  routing::NetZoneImpl* englobing_zone_;
+
 public:
-  using Resource_T::Resource_T;
+  explicit LinkImpl(const std::string& name, s4u::Link::SharingPolicy sharing_policy,
+                    routing::NetZoneImpl* englobing_zone)
+      : Resource_T(name), sharing_policy_(sharing_policy), englobing_zone_(englobing_zone)
+  {
+  }
   /** @brief Get the bandwidth in bytes per second of current Link */
   virtual double get_bandwidth() const = 0;
   /** @brief Update the bandwidth in bytes per second of current Link */
@@ -29,8 +38,13 @@ public:
   virtual void set_latency(double value) = 0;
 
   /** @brief The sharing policy */
-  virtual void set_sharing_policy(s4u::Link::SharingPolicy policy, const s4u::NonLinearResourceCb& cb) = 0;
-  virtual s4u::Link::SharingPolicy get_sharing_policy() const                                          = 0;
+  virtual void set_sharing_policy(s4u::Link::SharingPolicy policy, const s4u::NonLinearResourceCb& cb)
+  {
+    sharing_policy_ = policy;
+  }
+  s4u::Link::SharingPolicy get_sharing_policy() const { return sharing_policy_; }
+
+  routing::NetZoneImpl* get_englobing_zone() const { return englobing_zone_; }
 
   /* setup the profile file with bandwidth events (peak speed changes due to external load).
    * Profile must contain percentages (value between 0 and 1). */
