@@ -32,8 +32,9 @@ static void update_bw_comm_start(const s4u::Comm& comm)
   }
 }
 
-WifiLinkImpl::WifiLinkImpl(const std::string& name, const std::vector<double>& bandwidths, lmm::System* system)
-    : StandardLinkImpl(name)
+WifiLinkImpl::WifiLinkImpl(const std::string& name, const std::vector<double>& bandwidths, lmm::System* system,
+                           routing::NetZoneImpl* englobing_zone)
+    : StandardLinkImpl(name, s4u::Link::SharingPolicy::WIFI, englobing_zone)
 {
   this->set_constraint(system->constraint_new(this, 1));
   for (auto bandwidth : bandwidths)
@@ -66,11 +67,6 @@ double WifiLinkImpl::get_host_rate(const s4u::Host* host) const
   return rate.peak * rate.scale;
 }
 
-s4u::Link::SharingPolicy WifiLinkImpl::get_sharing_policy() const
-{
-  return s4u::Link::SharingPolicy::WIFI;
-}
-
 size_t WifiLinkImpl::get_host_count() const
 {
   return host_rates_.size();
