@@ -36,7 +36,6 @@ public:
  ************/
 
 class CpuCas01 : public CpuImpl {
-  std::function<s4u::Host::CpuFactorCb> factor_cb_         = {}; // XBT_ATTRIB_DEPRECATED_v401
   std::function<double(s4u::Host&, double)> factor_cpu_cb_ = {};
 
 public:
@@ -47,7 +46,6 @@ public:
   CpuAction* execution_start(double size, double user_bound) override;
   CpuAction* execution_start(double size, int requested_cores, double user_bound) override;
   CpuAction* sleep(double duration) override;
-  void set_factor_cb(const std::function<s4u::Host::CpuFactorCb>& cb) override;
   void set_cpu_factor_cb(const std::function<double(s4u::Host&, double)>& cb) override;
 
 protected:
