@@ -367,17 +367,20 @@ NetworkNS3Model::~NetworkNS3Model()
   ns3::Simulator::Destroy();
 }
 
-StandardLinkImpl* NetworkNS3Model::create_link(const std::string& name, const std::vector<double>& bandwidths)
+StandardLinkImpl* NetworkNS3Model::create_link(const std::string& name, const std::vector<double>& bandwidths,
+                                               routing::NetZoneImpl* englobing_zone)
 {
   xbt_assert(bandwidths.size() == 1, "ns-3 links must use only 1 bandwidth.");
-  auto* link = new LinkNS3(name, bandwidths[0]);
+  auto* link = new LinkNS3(name, bandwidths[0], s4u::Link::SharingPolicy::SHARED, englobing_zone);
   link->set_model(this);
   return link;
 }
 
-StandardLinkImpl* NetworkNS3Model::create_wifi_link(const std::string& name, const std::vector<double>& bandwidths)
+StandardLinkImpl* NetworkNS3Model::create_wifi_link(const std::string& name, const std::vector<double>& bandwidths,
+                                                    routing::NetZoneImpl* englobing_zone)
 {
-  auto* link = create_link(name, bandwidths);
+  xbt_assert(bandwidths.size() == 1, "ns-3 links must use only 1 bandwidth.");
+  auto* link = new LinkNS3(name, bandwidths[0], s4u::Link::SharingPolicy::WIFI, englobing_zone);
   link->set_sharing_policy(s4u::Link::SharingPolicy::WIFI, {});
   return link;
 }
@@ -390,25 +393,6 @@ Action* NetworkNS3Model::communicate(s4u::Host* src, s4u::Host* dst, double size
   return new NetworkNS3Action(this, size, src, dst);
 }
 
-#if SIMGRID_HAVE_NS3_GetNextEventTime
-/* If patched, ns3 is idempotent and nice to use */
-bool NetworkNS3Model::next_occurring_event_is_idempotent()
-{
-  return true;
-}
-
-double NetworkNS3Model::next_occurring_event(double sg_time)
-{
-  if (get_started_action_set()->empty()) {
-    return -1.0;
-  }
-
-  double ns3_time = ns3::Simulator::GetNextEventTime().GetSeconds();
-  XBT_DEBUG("NS3 tells that the next occuring event is at %f (it's %f in SimGrid), so NS3 returns a delta of %f.",
-            ns3_time, sg_time, ns3_time - sg_time);
-  return ns3_time - sg_time;
-}
-#else
 /* NS3 is only idempotent with the appropriate patch */
 bool NetworkNS3Model::next_occurring_event_is_idempotent()
 {
@@ -444,25 +428,11 @@ double NetworkNS3Model::next_occurring_event(double now)
 
   return time_to_next_flow_completion;
 }
-#endif
 
 void NetworkNS3Model::update_actions_state(double now, double delta)
 {
   static std::vector<std::string> socket_to_destroy;
 
-#if SIMGRID_HAVE_NS3_GetNextEventTime
-  /* If the ns-3 model is idempotent, it won't get updated in next_occurring_event() */
-
-  if (delta >= 0) {
-    XBT_DEBUG("DO START simulator delta: %f (current simgrid time: %f; current ns3 time: %f)", delta,
-              simgrid::kernel::EngineImpl::get_clock(), ns3::Simulator::Now().GetSeconds());
-    ns3_simulator(delta);
-  } else {
-    XBT_DEBUG("don't start simulator delta: %f (current simgrid time: %f; current ns3 time: %f)", delta,
-              simgrid::kernel::EngineImpl::get_clock(), ns3::Simulator::Now().GetSeconds());
-  }
-#endif
-
   for (const auto& [ns3_socket, sgFlow] : flow_from_sock) {
     NetworkNS3Action* action = sgFlow->action_;
     XBT_DEBUG("Processing flow %p (socket %s, action %p)", sgFlow, ns3_socket.c_str(), action);
@@ -514,7 +484,9 @@ void NetworkNS3Model::update_actions_state(double now, double delta)
  * Resource *
  ************/
 
-LinkNS3::LinkNS3(const std::string& name, double bandwidth) : StandardLinkImpl(name)
+LinkNS3::LinkNS3(const std::string& name, double bandwidth, s4u::Link::SharingPolicy sharing_policy,
+                 routing::NetZoneImpl* englobing_zone)
+    : StandardLinkImpl(name, sharing_policy, englobing_zone)
 {
   bandwidth_.peak = bandwidth;
 }
@@ -541,10 +513,6 @@ void LinkNS3::set_latency(double latency)
   latency_.peak = latency;
 }
 
-void LinkNS3::set_sharing_policy(s4u::Link::SharingPolicy policy, const s4u::NonLinearResourceCb& cb)
-{
-  sharing_policy_ = policy;
-}
 /**********
  * Action *
  **********/
@@ -640,9 +608,6 @@ void ns3_simulator(double maxSeconds) // maxSecond is a delay, not an absolute t
 
   XBT_DEBUG("Start simulator for at most %fs (current simgrid time: %f; current ns3 time: %f)", maxSeconds,
             simgrid::kernel::EngineImpl::get_clock(), ns3::Simulator::Now().GetSeconds());
-#if SIMGRID_HAVE_NS3_GetNextEventTime
-  xbt_assert(maxSeconds >= 0.0);
-#endif
   ns3::Simulator::Run();
   XBT_DEBUG("ns3 simulator stopped at %fs", ns3::Simulator::Now().GetSeconds());
 
