@@ -12,24 +12,29 @@
 #include "src/mc/mc_exit.hpp"
 #include "src/mc/mc_private.hpp"
 #include "src/mc/remote/CheckerSide.hpp"
+#include "src/mc/remote/mc_protocol.h"
 #include "xbt/asserts.h"
 #include "xbt/backtrace.hpp"
 #include "xbt/log.h"
 #include "xbt/system_error.hpp"
-#include <cstring>
-#include <limits>
-#include <signal.h>
+#include "xbt/thread.hpp"
 
 #include <algorithm>
 #include <array>
+#include <cstring>
 #include <limits.h>
+#include <limits>
 #include <memory>
+#include <mutex>
 #include <numeric>
+#include <optional>
+#include <signal.h>
 #include <string>
 #include <sys/ptrace.h>
 #include <sys/socket.h>
 #include <sys/un.h>
 #include <sys/wait.h>
+#include <vector>
 
 #ifdef __linux__
 #include <sys/personality.h>
@@ -39,26 +44,36 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_session, mc, "Model-checker session");
 XBT_LOG_EXTERNAL_CATEGORY(mc_global);
 
 namespace simgrid::mc {
+std::vector<std::string> master_socket_names;
+std::mutex mtx_master_socket_names;
 
-static std::string master_socket_name;
-
-RemoteApp::RemoteApp(const std::vector<char*>& args) : app_args_(args)
+RemoteApp::RemoteApp(const std::vector<char*>& args, const std::string additionnal_name) : app_args_(args)
 {
   master_socket_ = socket(AF_UNIX, SOCK_STREAM, 0);
   xbt_assert(master_socket_ != -1, "Cannot create the master socket: %s", strerror(errno));
 
-  master_socket_name = "/tmp/simgrid-mc-" + std::to_string(getpid());
+  master_socket_name = "/tmp/simgrid-mc-" + std::to_string(getpid()) + '-' + additionnal_name;
+  xbt_assert(master_socket_name.length() < MC_SOCKET_NAME_LEN,
+             "The socket name is too long for the affected size, probably because of the tid. Fix Me");
+
   master_socket_name.resize(MC_SOCKET_NAME_LEN); // truncate socket name if it's too long
   master_socket_name.back() = '\0';              // ensure the data are null-terminated
 #ifdef __linux__
   master_socket_name[0] = '\0'; // abstract socket, automatically removed after close
 #else
+  mtx_master_socket_names.lock();
   unlink(master_socket_name.c_str()); // remove possible stale socket before bind
-  atexit([]() {
-    if (not master_socket_name.empty())
-      unlink(master_socket_name.c_str());
-    master_socket_name.clear();
-  });
+  if (master_socket_names.empty()) {
+    atexit([]() {
+      for (auto& master_socket_name : master_socket_names) {
+        if (not master_socket_name.empty())
+          unlink(master_socket_name.c_str());
+        master_socket_name.clear();
+      }
+    });
+  }
+  master_socket_names.push_back(master_socket_name);
+  mtx_master_socket_names.unlock();
 #endif
 
   struct sockaddr_un serv_addr = {};
@@ -118,7 +133,7 @@ unsigned long RemoteApp::get_maxpid() const
   return answer->value;
 }
 
-void RemoteApp::get_actors_status(std::map<aid_t, ActorState>& whereto) const
+void RemoteApp::get_actors_status(std::vector<std::optional<ActorState>>& whereto) const
 {
   // The messaging happens as follows:
   //
@@ -132,8 +147,7 @@ void RemoteApp::get_actors_status(std::map<aid_t, ActorState>& whereto) const
   // unlock actors.
 
   if (not checker_side_->get_one_way()) {
-    s_mc_message_actors_status_t msg = {MessageType::ACTORS_STATUS,
-                                        Exploration::get_instance()->need_actor_status_transitions()};
+    s_mc_message_actors_status_t msg = {MessageType::ACTORS_STATUS, Exploration::need_actor_status_transitions()};
     checker_side_->get_channel().send(msg);
   }
 
@@ -152,7 +166,6 @@ void RemoteApp::get_actors_status(std::map<aid_t, ActorState>& whereto) const
              "short int to save memory. Such app is probably too big for MC anyway.",
              std::numeric_limits<short>::max());
 
-  whereto.clear();
   if (actor_count > 0) {
     size_t size           = actor_count * sizeof(s_mc_message_actors_status_one_t);
     auto [more_data, got] = checker_side_->get_channel().receive(size);
@@ -163,9 +176,13 @@ void RemoteApp::get_actors_status(std::map<aid_t, ActorState>& whereto) const
 
     for (int i = 0; i < actor_count; i++) {
       const auto& actor = status[i];
+
+      if ((unsigned)actor.aid >= whereto.size())
+        whereto.resize(actor.aid + 1);
+
       std::vector<std::shared_ptr<Transition>> actor_transitions;
 
-      if (Exploration::get_instance()->need_actor_status_transitions()) {
+      if (Exploration::need_actor_status_transitions()) {
         int n_transitions = actor.max_considered;
         for (int times_considered = 0; times_considered < n_transitions; times_considered++) {
           actor_transitions.emplace_back(
@@ -177,16 +194,17 @@ void RemoteApp::get_actors_status(std::map<aid_t, ActorState>& whereto) const
         XBT_DEBUG("No need for the actor transitions today");
       }
 
-      whereto.try_emplace(actor.aid, actor.aid, actor.enabled, actor.max_considered, std::move(actor_transitions));
+      whereto[actor.aid].emplace(actor.aid, actor.enabled, actor.max_considered, std::move(actor_transitions));
     }
   }
   XBT_DEBUG("Done receiving ACTORS_STATUS_REPLY");
-  for (auto kv : whereto) {
-    ActorState state = kv.second;
-    XBT_DEBUG("Actor %ld is %s, %s/%s/%s considered %u/%u with %lu transitions", kv.first,
-              state.is_enabled() ? "enabled" : "disabled", state.is_todo() ? "todo" : "-",
-              state.is_done() ? "done" : "-", state.is_unknown() ? "unknown" : "-", state.get_times_considered(),
-              state.get_max_considered(), state.get_enabled_transitions().size());
+  for (auto state : whereto) {
+    if (state.has_value())
+      XBT_DEBUG("Actor %hd is %s, %s/%s/%s considered %u/%u with %lu transitions", state.value().get_aid(),
+                state.value().is_enabled() ? "enabled" : "disabled", state.value().is_todo() ? "todo" : "-",
+                state.value().is_done() ? "done" : "-", state.value().is_unknown() ? "unknown" : "-",
+                state.value().get_times_considered(), state.value().get_max_considered(),
+                state.value().get_enabled_transitions().size());
   }
 }
 
@@ -200,8 +218,8 @@ bool RemoteApp::check_deadlock(bool verbose) const
     verbose = false;
 
   s_mc_message_int_t request = {};
-  request.type  = MessageType::DEADLOCK_CHECK;
-  request.value = verbose;
+  request.type               = MessageType::DEADLOCK_CHECK;
+  request.value              = verbose;
   xbt_assert(checker_side_->get_channel().send(request) == 0, "Could not check deadlock state");
 
   auto answer = (s_mc_message_int_t*)checker_side_->get_channel().expect_message(
@@ -227,7 +245,7 @@ void RemoteApp::wait_for_requests()
   checker_side_->wait_for_requests();
 }
 
-Transition* RemoteApp::handle_simcall(aid_t aid, int times_considered, bool new_transition)
+Transition* RemoteApp::handle_simcall(aid_t aid, int times_considered, bool new_transition) const
 {
   XBT_DEBUG("Handle simcall of pid %d (time considered: %d; %s)", (int)aid, times_considered,
             (new_transition ? "newly considered -- not replay" : "replay"));
@@ -235,9 +253,10 @@ Transition* RemoteApp::handle_simcall(aid_t aid, int times_considered, bool new_
   return checker_side_->handle_simcall(aid, times_considered, new_transition);
 }
 
-void RemoteApp::replay_sequence(std::deque<std::pair<aid_t, int>> to_replay)
+void RemoteApp::replay_sequence(std::deque<std::pair<aid_t, int>> to_replay,
+                                std::deque<std::pair<aid_t, int>> to_replay_and_actor_status)
 {
-  checker_side_->handle_replay(to_replay);
+  checker_side_->handle_replay(to_replay, to_replay_and_actor_status);
 }
 
 void RemoteApp::finalize_app(bool terminate_asap)
