@@ -50,8 +50,11 @@ protected:
 
   FILE* dot_output_ = nullptr;
 
+  bool one_way_disabled_ = false;
+
 public:
-  explicit Exploration(const std::vector<char*>& args);
+  explicit Exploration();
+  void initialize_remote_app(const std::vector<char*>& args) { remote_app_ = std::make_unique<RemoteApp>(args); }
   explicit Exploration(std::unique_ptr<RemoteApp> remote_app);
   virtual ~Exploration();
 
@@ -68,6 +71,9 @@ public:
    *  in corresponding states, and eventually rise an exception if we were looking for the critical transition. */
   void report_correct_execution(State* last_state);
 
+  /** Produce an error message corresponding to a data race in the application */
+  void report_data_race(const McDataRace& e);
+
   /** Produce an error message indicating that the application crashed (status was produced by waitpid) */
   XBT_ATTRIB_NORETURN void report_crash(int status);
   /** Produce an error message indicating that a property was violated */
@@ -92,7 +98,12 @@ public:
    * @param finalize_app wether we should try to finalize the app before rollbacking. This should always be done,
    *                     except if you already know that the application is dead.
    */
-  void backtrack_to_state(State* target_state, bool finalize_app = true);
+  void backtrack_to_state(State* target_state, bool finalize_app = true)
+  {
+    backtrack_remote_app_to_state(*remote_app_.get(), target_state, finalize_app);
+  }
+
+  void backtrack_remote_app_to_state(RemoteApp& remote_app, State* target_state, bool finalize_app = true);
 
   /* These methods are callbacks called by the model-checking engine
    * to get and display information about the current state of the
@@ -168,11 +179,17 @@ public:
 
   void run_critical_exploration_on_need(ExitStatus error);
 
-  bool need_actor_status_transitions()
+  static bool need_actor_status_transitions()
   {
     return _sg_mc_debug or get_model_checking_reduction() == ReductionMode::udpor;
   }
 
+  static bool can_go_one_way()
+  {
+    return _sg_mc_befs_threshold == 0 and _sg_mc_send_determinism == false and _sg_mc_comms_determinism == false and
+           not get_instance()->one_way_disabled_;
+  }
+
   /** Print something to the dot output file*/
   void dot_output(const char* fmt, ...) XBT_ATTRIB_PRINTF(2, 3);
 };
