@@ -4,22 +4,31 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/mc/explo/odpor/Execution.hpp"
+#include "src/kernel/activity/MemoryImpl.hpp"
+#include "src/mc/api/ClockVector.hpp"
 #include "src/mc/api/states/SleepSetState.hpp"
 #include "src/mc/api/states/State.hpp"
+#include "src/mc/explo/Exploration.hpp"
 #include "src/mc/explo/odpor/odpor_forward.hpp"
 #include "src/mc/mc_config.hpp"
+#include "src/mc/mc_exit.hpp"
 #include "src/mc/transition/Transition.hpp"
+#include "src/mc/transition/TransitionSynchro.hpp"
 #include "xbt/asserts.h"
 #include "xbt/backtrace.hpp"
 #include "xbt/log.h"
 #include "xbt/string.hpp"
 #include <algorithm>
+#include <exception>
+#include <iterator>
 #include <limits>
 #include <memory>
+#include <optional>
 #include <string>
 #include <vector>
 
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(mc_odpor_execution, mc_reduction, "ODPOR exploration algorithm of the model-checker");
+XBT_LOG_EXTERNAL_CATEGORY(mc_global);
 
 namespace simgrid::mc::odpor {
 
@@ -43,6 +52,75 @@ std::string one_string_textual_trace(const PartialExecution& w)
   return res;
 }
 
+void Event::initialize_epoch()
+{
+  aid_t event_aid_ = contents_.first->aid_;
+  for (auto rw : contents_.first->get_mem_op())
+    if (rw.get_type() == MemOpType::WRITE)
+      last_write_[rw.get_location()] = {event_aid_, contents_.second.get(event_aid_).value() - 1};
+}
+
+struct EventDataRace : public std::exception {
+  void* location_;
+  const MemOpType first_mem_op_;
+  const MemOpType second_mem_op_;
+  const EventHandle first_event_;
+  const EventHandle second_event_;
+  explicit EventDataRace(void* location, MemOpType first_mem_op, MemOpType second_mem_op, EventHandle first_event,
+                         EventHandle second_event)
+      : location_(location)
+      , first_mem_op_(first_mem_op)
+      , second_mem_op_(second_mem_op)
+      , first_event_(first_event)
+      , second_event_(second_event)
+  {
+  }
+};
+
+void Event::update_epoch_from(const ClockVector prev_clock, const Event prev_event)
+{
+  XBT_VERB("Updating epoch wiht %lu memory accesses", contents_.first->get_mem_op().size());
+  last_write_      = prev_event.last_write_;
+  aid_t event_aid_ = contents_.first->aid_;
+
+  for (auto rw : contents_.first->get_mem_op()) {
+    auto location   = rw.get_location();
+    auto prev_write = last_write_.find(location);
+
+    if (prev_write != last_write_.end() and prev_write->second.first == event_aid_) {
+      continue; // We just found an op that happened in the same transition, just after a previous write
+      // Obviously, those are not in race
+    }
+
+    if (rw.get_type() == MemOpType::READ) {
+
+      if (prev_write != last_write_.end()) {
+        auto [aid, clock] = prev_write->second;
+        if (clock >= prev_clock.get(aid).value()) {
+          throw EventDataRace(location, MemOpType::WRITE, MemOpType::READ, clock + 1,
+                              this->contents_.second.get(event_aid_).value());
+          // +1 is here to find the right transition in replay mode
+        }
+      }
+
+    } else {
+
+      if (prev_write != last_write_.end()) {
+        auto [aid, clock] = prev_write->second;
+        if (clock >= prev_clock.get(aid).value())
+          throw EventDataRace(location, MemOpType::WRITE, MemOpType::WRITE, clock + 1,
+                              this->contents_.second.get(event_aid_).value());
+        // +1 is here to find the right transition in replay mode
+      }
+
+      // Record the new write as it happened juste before this transition
+      // the -1 is here because we receive reads and writes AFTER the transition while
+      // in reality it happened BEFORE
+      last_write_[location] = {event_aid_, contents_.second.get(event_aid_).value() - 1};
+    }
+  }
+}
+
 PartialExecution Execution::preallocated_partial_execution_ = PartialExecution();
 
 Execution::Execution(const PartialExecution& w)
@@ -52,11 +130,15 @@ Execution::Execution(const PartialExecution& w)
 
 void Execution::push_transition(std::shared_ptr<Transition> t, bool are_we_restoring_execution)
 {
+
   xbt_assert(t != nullptr, "Unexpectedly received `nullptr`");
   ClockVector max_clock_vector;
+  // For each aid
   for (const auto& events : this->skip_list_) {
+    // Find the most recent event with which we are dependent
     for (auto event_it = events.crbegin(); event_it != events.crend(); ++event_it) {
       if (contents_[*event_it].get_transition()->depends(t.get())) {
+        // And update the clock to reflect this
         ClockVector::max_emplace_left(max_clock_vector, contents_[*event_it].get_clock_vector());
         break;
       }
@@ -66,10 +148,34 @@ void Execution::push_transition(std::shared_ptr<Transition> t, bool are_we_resto
   contents_.push_back(Event({t, std::move(max_clock_vector)}));
   if (skip_list_.size() <= (unsigned)t->aid_)
     skip_list_.resize(t->aid_ + 1, {});
+  EventHandle prev_event_of_aid = skip_list_[t->aid_].size() == 0 ? -1 : skip_list_[t->aid_].back();
   skip_list_[t->aid_].push_back(this->size() - 1);
 
   if (are_we_restoring_execution)
     contents_.back().consider_races();
+
+  if (contents_.size() == 1)
+    contents_.back().initialize_epoch();
+  else {
+    ClockVector clock =
+        prev_event_of_aid == (unsigned)-1 ? ClockVector(0) : contents_[prev_event_of_aid].get_clock_vector();
+    try {
+      contents_.back().update_epoch_from(clock, *(std::prev(contents_.end(), 2)));
+    } catch (EventDataRace& dr) {
+
+      aid_t first_aid  = contents_[dr.first_event_].get_transition()->aid_;
+      aid_t second_aid = contents_[dr.second_event_].get_transition()->aid_;
+
+      // count the number of previously recorded transition made by the corresponding actor
+      // this way the replayed app can pinpoint which transition has done the transition and display the right backtrace
+      long first_op  = std::count_if(contents_.begin(), contents_.begin() + dr.first_event_,
+                                     [&](auto event) { return event.get_transition()->aid_ == first_aid; });
+      long second_op = std::count_if(contents_.begin(), contents_.begin() + dr.second_event_,
+                                     [&](auto event) { return event.get_transition()->aid_ == second_aid; });
+
+      throw McDataRace({first_aid, first_op}, {second_aid, second_op}, dr.location_, dr.second_mem_op_);
+    }
+  }
 }
 
 void Execution::remove_last_event()
@@ -156,16 +262,15 @@ std::list<Execution::EventHandle> Execution::get_racing_events_of(Execution::Eve
   return racing_events;
 }
 
-std::list<Execution::EventHandle> Execution::get_reversible_races_of(EventHandle handle) const
+std::list<Execution::EventHandle> Execution::get_reversible_races_of(EventHandle handle, stack_t* S) const
 {
   std::list<EventHandle> reversible_races;
   const auto* this_transition = get_transition_for_handle(handle);
   for (EventHandle race : get_racing_events_of(handle)) {
     const auto* other_transition = get_transition_for_handle(race);
-
-    if (this_transition->reversible_race(other_transition)) {
+    xbt_assert(race < handle); // other_transition --> this_transition
+    if (other_transition->reversible_race(this_transition, this, race, handle))
       reversible_races.push_back(race);
-    }
   }
   return reversible_races;
 }
@@ -296,6 +401,7 @@ std::optional<PartialExecution> Execution::get_odpor_extension_from(EventHandle
 
   XBT_DEBUG("... Sleepinging set at E_prime containing %s",
             std::accumulate(sleep_E_prime.begin(), sleep_E_prime.end(), std::string(), [](std::string a, aid_t b) {
+              xbt_assert(b != 0, "How did we create an actor 0??");
               return std::move(a) + ';' + std::to_string(b);
             }).c_str());
 
@@ -552,9 +658,11 @@ void MazurkiewiczTraces::record_new_execution(const Execution& exec)
       XBT_CRITICAL("Previous sequence was:\n%s", one_string_textual_trace(can_be_equivalent).c_str());
       XBT_CRITICAL("New one is:\n%s", one_string_textual_trace(seq).c_str());
       xbt_die("Fix me!");
+      return;
     }
   }
   classes_.insert(seq);
+  XBT_INFO("Currently recorded %zu traces", classes_.size());
 }
 
 void MazurkiewiczTraces::log_data()
