@@ -16,6 +16,7 @@
 #include <map>
 #include <optional>
 #include <set>
+#include <unordered_map>
 #include <unordered_set>
 #include <vector>
 
@@ -24,6 +25,9 @@ namespace simgrid::mc::odpor {
 std::vector<std::string> get_textual_trace(const PartialExecution& w);
 std::string one_string_textual_trace(const PartialExecution& w);
 
+// Data structure to implement FastTrack algorithm (see [Flanagan'09])
+using epoch = std::pair<aid_t, long>;
+
 /**
  * @brief The occurrence of a transition in an execution
  *
@@ -34,6 +38,8 @@ std::string one_string_textual_trace(const PartialExecution& w);
 class Event {
   std::pair<std::shared_ptr<Transition>, ClockVector> contents_;
 
+  std::unordered_map<void*, epoch> last_write_;
+
   // Have reversible races between this event and its prefix already been computed ?
   mutable bool race_considered_ = false;
 
@@ -49,6 +55,8 @@ public:
 
   bool has_race_been_computed() const { return race_considered_; }
   void consider_races() const { race_considered_ = true; }
+  void initialize_epoch();
+  void update_epoch_from(const ClockVector prev_clock, const Event prev_event);
 };
 
 /**
@@ -319,10 +327,12 @@ public:
    *
    * @param handle the event with respect to which
    * reversible races are computed
+   * @param S the stack of states. This is used to help determine wether a
+   * race is truly reversible
    * @returns a set of event handles, each element of which is an event
    * in this execution which is in a *reversible race* with event `handle`
    */
-  std::list<EventHandle> get_reversible_races_of(EventHandle handle) const;
+  std::list<EventHandle> get_reversible_races_of(EventHandle handle, stack_t* S) const;
 
   /**
    * @brief Computes `pre(e, E)` as described in ODPOR [1]
@@ -400,6 +410,12 @@ public:
    *
    */
   static bool is_in_weak_initial_of(Transition*, const PartialExecution&);
+
+  /**
+   * @brief Computes wether the sequence without the unlock can fire the wait
+   *
+   */
+  bool is_sem_wait_fireable_without_unlock(EventHandle unlock_handle, EventHandle wait_handle) const;
 };
 
 class MazurkiewiczTraces {
