@@ -36,11 +36,13 @@ simgrid::config::Flag<std::string> _sg_mc_record_path{
     [](std::string_view value) {
       if (value.empty()) // Ignore default value
         return;
-      xbt_assert(simgrid::mc::get_model_checking_mode() == simgrid::mc::ModelCheckingMode::NONE ||
-                     simgrid::mc::get_model_checking_mode() == simgrid::mc::ModelCheckingMode::REPLAY,
-                 "Specifying a MC replay path is not allowed when running the model-checker in mode %s. "
-                 "Either remove the model-check/replay parameter, or execute your code out of simgrid-mc.",
-                 to_c_str(simgrid::mc::get_model_checking_mode()));
+      if (simgrid::mc::get_model_checking_mode() != simgrid::mc::ModelCheckingMode::NONE &&
+          simgrid::mc::get_model_checking_mode() != simgrid::mc::ModelCheckingMode::REPLAY &&
+          /* simgrid-mc will execve the binary to remove itself when this parameter is set */
+          simgrid::mc::get_model_checking_mode() != simgrid::mc::ModelCheckingMode::CHECKER_SIDE)
+        xbt_die("ERROR: Specifying a MC replay path is not allowed when running the model-checker in mode %s. "
+                "Either remove the model-check/replay parameter, or execute your code out of simgrid-mc.",
+                to_c_str(simgrid::mc::get_model_checking_mode()));
       simgrid::mc::set_model_checking_mode(simgrid::mc::ModelCheckingMode::REPLAY);
       MC_record_path() = value;
     }};
@@ -51,11 +53,11 @@ simgrid::config::Flag<bool> _sg_mc_timeout{
     }};
 
 static simgrid::config::Flag<std::string> cfg_mc_reduction{
-    "model-check/reduction", "Specify the kind of exploration reduction (either none or DPOR)", "dpor",
+    "model-check/reduction", "Specify the kind of exploration reduction (none, DPOR, ODPOR or UDPOR)", "dpor",
     [](std::string_view value) {
       if (value != "none" && value != "dpor" && value != "sdpor" && value != "odpor" && value != "udpor")
         xbt_die("configuration option 'model-check/reduction' must be one of the following: "
-                " 'none', 'dpor', 'sdpor', 'odpor', or 'udpor'");
+                " 'dpor', 'sdpor', 'odpor', or 'udpor'");
     }};
 
 simgrid::config::Flag<int> _sg_mc_cached_states_interval{
@@ -64,6 +66,12 @@ simgrid::config::Flag<int> _sg_mc_cached_states_interval{
     1000,
     [](int val) { xbt_assert(val >= 0, "The value of model-check/cached-states-interval must be positive or null"); }};
 
+simgrid::config::Flag<int> _sg_mc_parallel_thread{
+    "model-check/parallel-thread",
+    "Specify how explorer should be launched in parallel. Each explorer will be a different separate thread spawned by "
+    "McSimGrid.",
+    1, [](int val) { xbt_assert(val >= 1, "The value of model-check/parallel-thread must be >= 1"); }};
+
 simgrid::config::Flag<std::string> _sg_mc_explore_algo{
     "model-check/exploration-algo",
     "Specify the type of search politic to use in MC algorithm",
@@ -109,11 +117,17 @@ simgrid::config::Flag<bool> _sg_mc_debug{
     "Whether to enable advance runtime verification. Those may be costly and therefore are desactivated by default.",
     false, [](bool) { _mc_cfg_cb_check("value to enable/disable advance runtime verification"); }};
 
-simgrid::config::Flag<bool> _sg_mc_debug_soundness{
-    "model-check/debug-soundness",
+simgrid::config::Flag<bool> _sg_mc_debug_optimality{
+    "model-check/debug-optimality",
     "Whether to enable advance runtime verification. Those may be costly and therefore are desactivated by default.",
     false, [](bool) { _mc_cfg_cb_check("value to enable/disable advance runtime verification"); }};
 
+simgrid::config::Flag<bool> _sg_mc_output_lts{"model-check/output-lts",
+                                              "Whether to print informations about the explored LTS.", false,
+                                              [](bool) { _mc_cfg_cb_check("value to enable/disable LTS printing"); }};
+// In a perfect world, We should use the already existing dot output system
+// TODO
+
 simgrid::config::Flag<std::string> _sg_mc_buffering{
     "smpi/buffering",
     "Buffering semantic to use for MPI (only used in MC)",
