@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -11,6 +11,10 @@
 #ifndef SIMGRID_MC_FORWARD_HPP
 #define SIMGRID_MC_FORWARD_HPP
 
+#include "simgrid/forward.h"
+#include "src/mc/xbt_intrusiveptr.hpp"
+#include <deque>
+
 namespace simgrid::mc {
 
 class PageStore;
@@ -27,6 +31,14 @@ class Frame;
 
 class Session;
 class Exploration;
+class SleepSetState;
+
+using StatePtr = boost::intrusive_ptr<State>;
+XBT_PUBLIC void intrusive_ptr_release(State* o);
+XBT_PUBLIC void intrusive_ptr_add_ref(State* o);
+
+using stack_t = std::deque<StatePtr>;
+
 } // namespace simgrid::mc
 
 #endif
