@@ -98,6 +98,28 @@ void AppSide::handle_deadlock_check(const s_mc_message_int_t* request)
   answer.value              = deadlock;
   xbt_assert(channel_.send(answer) == 0, "Could not send response: %s", strerror(errno));
 }
+
+void AppSide::send_executed_transition(kernel::actor::ActorImpl* actor, bool want_transition)
+{
+  s_mc_message_simcall_execute_answer_t answer{};
+  answer.type = MessageType::SIMCALL_EXECUTE_REPLY;
+  answer.aid  = actor->get_pid();
+  channel_.pack(answer);
+
+  if (want_transition) {
+    if (actor->simcall_.observer_ != nullptr) {
+      actor->simcall_.observer_->serialize(channel_);
+      actor->recorded_memory_accesses_->serialize(channel_);
+    } else {
+      channel_.pack(mc::Transition::Type::UNKNOWN);
+    }
+    XBT_VERB("send SIMCALL_EXECUTE_REPLY(%s:%ld) with a transition", actor->get_cname(), actor->get_pid());
+  } else
+    XBT_VERB("send SIMCALL_EXECUTE_REPLY(%s:%ld) with no transition inside", actor->get_cname(), actor->get_pid());
+
+  xbt_assert(channel_.send() == 0, "Could not send response: %s", strerror(errno));
+}
+
 void AppSide::handle_simcall_execute(const s_mc_message_simcall_execute_t* message)
 {
   kernel::actor::ActorImpl* actor = kernel::EngineImpl::get_instance()->get_actor_by_pid(message->aid_);
@@ -115,26 +137,12 @@ void AppSide::handle_simcall_execute(const s_mc_message_simcall_execute_t* messa
              strerror(errno));
 
   // Finish the RPC from the server: return a serialized observer, to build a Transition on Checker side
-  s_mc_message_simcall_execute_answer_t answer{};
-  answer.type = MessageType::SIMCALL_EXECUTE_REPLY;
-  answer.aid  = actor->get_pid();
-  channel_.pack(answer);
-
-  if (message->want_transition) {
-    if (actor->simcall_.observer_ != nullptr) {
-      actor->simcall_.observer_->serialize(channel_);
-    } else {
-      channel_.pack(mc::Transition::Type::UNKNOWN);
-    }
-    XBT_VERB("send SIMCALL_EXECUTE_REPLY(%s:%ld) with a transition", actor->get_cname(), actor->get_pid());
-  } else
-    XBT_VERB("send SIMCALL_EXECUTE_REPLY(%s:%ld) with no transition inside", actor->get_cname(), actor->get_pid());
-
-  xbt_assert(channel_.send() == 0, "Could not send response: %s", strerror(errno));
+  send_executed_transition(actor, message->want_transition);
 }
 
 void AppSide::handle_replay(const s_mc_message_int_t* msg)
 {
+  XBT_DEBUG("Starting to handle the replay");
   unsigned replay_size = msg->value;
 
   auto [more_aid, aids] = channel_.receive(sizeof(unsigned char) * replay_size);
@@ -145,11 +153,16 @@ void AppSide::handle_replay(const s_mc_message_int_t* msg)
   if (not more_times)
     ::_Exit(0); // Nobody's listening to that process anymore => exit as quickly as possible.
 
-  XBT_DEBUG("Going to replay %u transitions", replay_size);
-  for (unsigned i = 0; i < replay_size; i++) {
+  XBT_DEBUG("Going to replay %u transitions", replay_size - 1);
+  unsigned i = 0;
+  for (; i < replay_size; i++) {
     aid_t aid            = ((unsigned char*)aids)[i];
     int times_considered = ((unsigned char*)times)[i];
 
+    // The -1 value is used to indicate the part requiring transition and status
+    if (aid == 255 and times_considered == 255) // -1 in unsigned char
+      break;
+
     XBT_VERB("MC asked to replay %ld(nb_times=%d)", aid, times_considered);
     kernel::actor::ActorImpl* actor = kernel::EngineImpl::get_instance()->get_actor_by_pid(aid);
     xbt_assert(actor != nullptr, "Invalid pid %ld", aid);
@@ -162,16 +175,48 @@ void AppSide::handle_replay(const s_mc_message_int_t* msg)
     actor->simcall_handle(times_considered);
     simgrid::mc::execute_actors();
   }
+  i++;
+  XBT_DEBUG("Now going to ask for actor status for the next %u transitions", replay_size - i - 1);
+  if (i >= replay_size)
+    // Say the server that the replay is over and that it should proceed
+    xbt_assert(channel_.send(MessageType::WAITING) == 0, "Could not send MESSAGE_WAITING to model-checker: %s",
+               strerror(errno));
 
-  // Say the server that the replay is over and that it should proceed
-  xbt_assert(channel_.send(MessageType::WAITING) == 0, "Could not send MESSAGE_WAITING to model-checker: %s",
-             strerror(errno));
+  // else, the actor status will tell when the replay is over
+  for (; i < replay_size; i++) {
+    aid_t aid            = ((unsigned char*)aids)[i];
+    int times_considered = ((unsigned char*)times)[i];
+
+    XBT_VERB("MC asked to replay %ld(nb_times=%d)", aid, times_considered);
+    kernel::actor::ActorImpl* actor = kernel::EngineImpl::get_instance()->get_actor_by_pid(aid);
+    xbt_assert(actor != nullptr, "Invalid pid %ld", aid);
+    xbt_assert((actor->simcall_.observer_ == nullptr &&
+                actor->simcall_.call_ != simgrid::kernel::actor::Simcall::Type::NONE) ||
+                   (actor->simcall_.observer_ != nullptr && actor->simcall_.observer_->is_enabled()),
+               "Please, model-checker, don't execute disabled transitions. You tried to execute %s which is disabled",
+               actor->simcall_.observer_->to_string().c_str());
+
+    actor->simcall_handle(times_considered);
+    // The checker is asking for this message specifically to update the incoming
+    // transition, so let's sent it with 'true'
+    send_executed_transition(actor, true);
+
+    simgrid::mc::execute_actors();
+    // The false doesn't look safe, and it would be better to modify the msg content to rlly know if the checker want
+    // the transition or not
+    send_actor_status(false);
+  }
 }
 
 void AppSide::handle_one_way(const s_mc_message_one_way_t* msg)
 {
-  auto* engine = kernel::EngineImpl::get_instance();
-  bool is_random = msg->is_random;
+  auto* engine                   = kernel::EngineImpl::get_instance();
+  bool is_random                 = msg->is_random;
+  static bool initialized_random = false;
+  if (not initialized_random and is_random) {
+    xbt::random::set_mersenne_seed(msg->random_seed);
+    initialized_random = true;
+  }
 
   std::vector<aid_t> fireables;
   for (auto const& [aid, actor] : engine->get_actor_list())
@@ -200,20 +245,8 @@ void AppSide::handle_one_way(const s_mc_message_one_way_t* msg)
     // hence, let's play the transition with considered_times = 0
     actor->simcall_handle(0);
 
-    // Sending the transition message
-    s_mc_message_simcall_execute_answer_t transition_execute_msg = {};
-    transition_execute_msg.type = MessageType::SIMCALL_EXECUTE_REPLY;
-    transition_execute_msg.aid                                   = chosen_aid;
-    channel_.pack(transition_execute_msg);
-
-    if (actor->simcall_.observer_ != nullptr) {
-      actor->simcall_.observer_->serialize(channel_);
-    } else {
-      channel_.pack(mc::Transition::Type::UNKNOWN);
-    }
-    XBT_VERB("send SIMCALL_EXECUTE_ANSWER(%s) ", actor->get_cname());
-    xbt_assert(channel_.send() == 0, "Could not send response: %s", strerror(errno));
-
+    // Sending the transition message with the actual transition
+    send_executed_transition(actor, true);
     // Make a step in the app
     simgrid::mc::execute_actors(); // May raise assertion errors, every packed data must be send before this.
 
@@ -305,7 +338,7 @@ void AppSide::handle_fork(const s_mc_message_fork_t* msg)
 
     xbt_die("The SimGrid model-checker cannot handle the threaded context factory because it relies on forking the "
             "application, which is not possible with multi-threaded applications. Please remove the "
-            "--cfg=contexts/factory:thread parameter to the application, or add --cfg=model-check/no-fork:1 to "
+            "--cfg=contexts/factory:thread parameter to the application, or add --cfg=model-check/no-fork:on to "
             "simgrid-mc. The second option results in slower explorations, but it is the only option when verifying "
             "Python programs, as the SimGrid Python bindings mandate threads.");
     // See also commit c2c077dc7edb4a4217610dbaf675f414cbf6f09f for the reason why Python needs threads
@@ -358,7 +391,8 @@ void AppSide::handle_wait_child(const s_mc_message_int_t* msg)
   answer.value              = status;
   xbt_assert(channel_.send(answer) == 0, "Could not send response to WAIT_CHILD: %s", strerror(errno));
 }
-void AppSide::handle_actors_status(const s_mc_message_actors_status_t* msg)
+
+void AppSide::send_actor_status(bool want_transitions)
 {
   auto const& actor_list = kernel::EngineImpl::get_instance()->get_actor_list();
   XBT_DEBUG("Serialize the actors to answer ACTORS_STATUS from the checker. %zu actors to go.", actor_list.size());
@@ -388,7 +422,7 @@ void AppSide::handle_actors_status(const s_mc_message_actors_status_t* msg)
 
     channel_.pack(status, status_size);
 
-    if (msg->want_transitions_) {
+    if (want_transitions) {
       // Serialize each transition to describe what each actor is doing
       XBT_DEBUG("pack the transitions");
       for (int i = 0; i < answer.count; i++) {
@@ -412,10 +446,16 @@ void AppSide::handle_actors_status(const s_mc_message_actors_status_t* msg)
     } else {
       XBT_DEBUG("Do not pack the transitions: the checker don't want them");
     }
+  }
+  xbt_assert(channel_.send() == 0, "Could not send ACTORS_STATUS_REPLY: %s", strerror(errno));
+  XBT_DEBUG("Done sending ACTORS_STATUS_REPLY");
 }
-xbt_assert(channel_.send() == 0, "Could not send ACTORS_STATUS_REPLY: %s", strerror(errno));
-XBT_DEBUG("Done sending ACTORS_STATUS_REPLY");
+
+void AppSide::handle_actors_status(const s_mc_message_actors_status_t* msg)
+{
+  send_actor_status(msg->want_transitions_);
 }
+
 void AppSide::handle_actors_maxpid()
 {
   s_mc_message_int_t answer = {};
