@@ -11,7 +11,6 @@
 #ifdef __cplusplus
 
 #include "simgrid/forward.h" // aid_t
-#include "src/mc/datatypes.h"
 #include <xbt/utility.hpp>
 
 #include <array>
@@ -85,6 +84,7 @@ struct s_mc_message_one_way_t {
   simgrid::mc::MessageType type;
   bool want_transitions;
   bool is_random;
+  int random_seed;
 };
 
 struct s_mc_message_actors_status_one_t { // an array of `s_mc_message_actors_status_one_t[count]` is sent right after
