@@ -5,6 +5,7 @@
 
 #include "src/mc/transition/TransitionAny.hpp"
 #include "simgrid/config.h"
+#include "src/mc/transition/TransitionComm.hpp"
 #include "xbt/asserts.h"
 #include "xbt/string.hpp"
 
@@ -40,12 +41,10 @@ bool TestAnyTransition::depends(const Transition* other) const
   // Actions executed by the same actor are always dependent
   if (other->aid_ == aid_)
     return true;
-  for (auto const& transition : transitions_)
-    if (transition->depends(other))
-      return true;
-  return false;
+  return this->get_current_transition()->depends(other);
 }
-bool TestAnyTransition::reversible_race(const Transition* other) const
+bool TestAnyTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                        EventHandle other_handle) const
 {
   xbt_assert(type_ == Type::TESTANY, "Unexpected transition type %s", to_c_str(type_));
 
@@ -76,20 +75,33 @@ bool WaitAnyTransition::depends(const Transition* other) const
   // Actions executed by the same actor are always dependent
   if (other->aid_ == aid_)
     return true;
-  for (auto const& transition : transitions_)
-    if (transition->depends(other))
-      return true;
-  return false;
+  return this->get_current_transition()->depends(other);
 }
-bool WaitAnyTransition::reversible_race(const Transition* other) const
+
+Transition* WaitAnyTransition::get_current_transition() const
+{
+  int times_considered = times_considered_;
+  for (auto* t : transitions_) {
+    auto const* wait = static_cast<const CommWaitTransition*>(t);
+
+    if (not wait->is_enabled())
+      continue;
+
+    if (times_considered == 0)
+      return t;
+    else
+      times_considered--;
+  }
+
+  xbt_die("There is no enabled corresponding transition. Fix me!");
+}
+
+bool WaitAnyTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                        EventHandle other_handle) const
 {
   xbt_assert(type_ == Type::WAITANY, "Unexpected transition type %s", to_c_str(type_));
 
-  for (auto const& transition : transitions_)
-    if (transition->reversible_race(other))
-      return true; // Let's overapproximate to not miss branches, if we can reverse any transition, let's go for it
-
-  return false;
+  return this->reversible_race(other, exec, this_handle, other_handle);
 }
 
 } // namespace simgrid::mc
