@@ -6,6 +6,7 @@
 #include "src/mc/transition/TransitionComm.hpp"
 #include "simgrid/config.h"
 #include "src/mc/api/RemoteApp.hpp"
+#include "src/mc/transition/TransitionAny.hpp"
 #include "xbt/asserts.h"
 #include "xbt/log.h"
 #include "xbt/string.hpp"
@@ -70,12 +71,13 @@ bool CommWaitTransition::depends(const Transition* other) const
   return false; // Comm transitions are INDEP with non-comm transitions
 }
 
-bool CommWaitTransition::reversible_race(const Transition* other) const
+bool CommWaitTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                         EventHandle other_handle) const
 {
   xbt_assert(type_ == Type::COMM_WAIT, "Unexpected transition type %s", to_c_str(type_));
 
-  // If the other event is a communication event, then we are not reversible; otherwise we are reversible.
-  return other->type_ != Transition::Type::COMM_ASYNC_SEND && other->type_ != Transition::Type::COMM_ASYNC_RECV;
+  // The only case that could be blocking is an other wait transition
+  return other->type_ != Type::COMM_WAIT;
 }
 
 CommTestTransition::CommTestTransition(aid_t issuer, int times_considered, unsigned comm_, aid_t sender_,
@@ -128,7 +130,8 @@ bool CommTestTransition::depends(const Transition* other) const
   return false; // Comm transitions are INDEP with non-comm transitions
 }
 
-bool CommTestTransition::reversible_race(const Transition* other) const
+bool CommTestTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                         EventHandle other_handle) const
 {
   xbt_assert(type_ == Type::COMM_TEST, "Unexpected transition type %s", to_c_str(type_));
   return true; // CommTest is always enabled
@@ -213,11 +216,26 @@ bool CommRecvTransition::depends(const Transition* other) const
   return false; // Comm transitions are INDEP with non-comm transitions
 }
 
-bool CommRecvTransition::reversible_race(const Transition* other) const
+bool CommRecvTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                         EventHandle other_handle) const
 {
   xbt_assert(type_ == Type::COMM_ASYNC_RECV, "Unexpected transition type %s", to_c_str(type_));
 
-  return true; // CommRecv is always enabled
+  // If this recv enabled the comm_wait, then it's not reversible
+  if (other->type_ == Type::COMM_WAIT) {
+    const auto* wait = static_cast<const CommWaitTransition*>(other);
+    if (wait->comm_ == this->comm_)
+      return false;
+  }
+
+  if (other->type_ == Type::WAITANY) {
+    const auto* wait =
+        static_cast<const CommWaitTransition*>(static_cast<const WaitAnyTransition*>(other)->get_current_transition());
+    if (wait->comm_ == this->comm_)
+      return false;
+  }
+
+  return true;
 }
 
 CommSendTransition::CommSendTransition(aid_t issuer, int times_considered, unsigned comm_, unsigned mbox_, int tag_)
@@ -300,11 +318,26 @@ bool CommSendTransition::depends(const Transition* other) const
   return false; // Comm transitions are INDEP with non-comm transitions
 }
 
-bool CommSendTransition::reversible_race(const Transition* other) const
+bool CommSendTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                         EventHandle other_handle) const
 {
   xbt_assert(type_ == Type::COMM_ASYNC_SEND, "Unexpected transition type %s", to_c_str(type_));
 
-  return true; // CommSend is always enabled
+  // If this send enabled the comm_wait, then it's not reversible
+  if (other->type_ == Type::COMM_WAIT) {
+    const auto* wait = static_cast<const CommWaitTransition*>(other);
+    if (wait->comm_ == this->comm_)
+      return false;
+  }
+
+  if (other->type_ == Type::WAITANY) {
+    const auto* wait =
+        static_cast<const CommWaitTransition*>(static_cast<const WaitAnyTransition*>(other)->get_current_transition());
+    if (wait->comm_ == this->comm_)
+      return false;
+  }
+
+  return true;
 }
 
 CommIprobeTransition::CommIprobeTransition(aid_t issuer, int times_considered, bool is_sender, unsigned mbox, int tag)
@@ -343,7 +376,8 @@ bool CommIprobeTransition::depends(const Transition* other) const
   // Iprobe can't enable a wait and is independent with every non Recv nor Send transition
   return false;
 }
-bool CommIprobeTransition::reversible_race(const Transition* other) const
+bool CommIprobeTransition::reversible_race(const Transition* other, const odpor::Execution* exec,
+                                           EventHandle this_handle, EventHandle other_handle) const
 {
   // In every cases, we can execute Iprobe before someone else
   return true;
