@@ -22,9 +22,10 @@ public:
   ObjectAccessTransition(aid_t issuer, int times_considered, mc::Channel& channel);
   std::string to_string(bool verbose) const override;
   bool depends(const Transition* other) const override;
-  bool reversible_race(const Transition* other) const override;
+  bool reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                       EventHandle other_handle) const override;
 };
 
 } // namespace simgrid::mc
 
-#endif
\ No newline at end of file
+#endif
