@@ -24,7 +24,8 @@ public:
 
     return aid_ == other->aid_;
   } // Independent with any other transition
-  bool reversible_race(const Transition* other) const override;
+  bool reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                       EventHandle other_handle) const override;
 };
 
 } // namespace simgrid::mc
