@@ -4,14 +4,17 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "src/mc/transition/TransitionSynchro.hpp"
+#include "src/mc/mc_config.hpp"
 #include "src/mc/mc_forward.hpp"
 #include "src/mc/transition/Transition.hpp"
 #include "src/mc/transition/TransitionActor.hpp"
 #include "src/mc/transition/TransitionObjectAccess.hpp"
 #include "xbt/asserts.h"
 #include "xbt/ex.h"
+#include "xbt/log.h"
 #include "xbt/string.hpp"
 
+#include <algorithm>
 #include <inttypes.h>
 #include <sstream>
 
@@ -54,21 +57,22 @@ bool BarrierTransition::depends(const Transition* o) const
 
   return false; // barriers are INDEP with non-barrier transitions
 }
-bool BarrierTransition::reversible_race(const Transition* other) const
+bool BarrierTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                        EventHandle other_handle) const
 {
-  if (other->type_ == Type::ACTOR_CREATE) {
-    const ActorCreateTransition* ctransition = static_cast<const ActorCreateTransition*>(other);
-    xbt_assert(aid_ == ctransition->get_child());
+  if (other->type_ == Type::ACTOR_JOIN) {
+    const ActorJoinTransition* ctransition = static_cast<const ActorJoinTransition*>(other);
+    xbt_assert(aid_ == ctransition->get_target());
     return false;
   }
 
-  switch (type_) {
+  switch (other->type_) {
     case Type::BARRIER_ASYNC_LOCK:
       return true; // BarrierAsyncLock is always enabled
     case Type::BARRIER_WAIT:
       // If the other event is a barrier lock event, then we are not reversible;
       // otherwise we are reversible.
-      return other->type_ != Transition::Type::BARRIER_ASYNC_LOCK;
+      return type_ != Transition::Type::BARRIER_ASYNC_LOCK;
     default:
       xbt_die("Unexpected transition type %s", to_c_str(type_));
   }
@@ -166,7 +170,7 @@ bool MutexTransition::can_be_co_enabled(const Transition* o) const
 
   } // mutex transition
 
-    // If someone can unlock, that someon has the mutex. Hence, nobody can wait on it
+  // If someone can unlock, that someon has the mutex. Hence, nobody can wait on it
   if (type_ == Type::MUTEX_UNLOCK && o->type_ == Type::MUTEX_WAIT)
     return false;
 
@@ -181,29 +185,77 @@ bool MutexTransition::can_be_co_enabled(const Transition* o) const
   return true; // mutexes are INDEP with non-mutex transitions
 }
 
-bool SemaphoreTransition::reversible_race(const Transition* other) const
+static bool is_sem_wait_fireable_without_unlock(const odpor::Execution* exec, EventHandle unlock_handle,
+                                                EventHandle wait_handle)
 {
-  if (other->type_ == Type::ACTOR_CREATE) {
-    const ActorCreateTransition* ctransition = static_cast<const ActorCreateTransition*>(other);
-    xbt_assert(aid_ == ctransition->get_child());
-    return false;
+  XBT_DEBUG(
+      "Expertise has been required in the following matter:%s\nIs the wait <%s> enabled if we remove the unlock <%s>",
+      exec->get_one_string_textual_trace().c_str(), exec->get_transition_for_handle(wait_handle)->to_string().c_str(),
+      exec->get_transition_for_handle(unlock_handle)->to_string().c_str());
+
+  unsigned sem_id  = static_cast<const SemaphoreTransition*>(exec->get_transition_for_handle(unlock_handle))->get_sem();
+  int max_capacity = -1;
+  int nb_lock      = 0;
+  int nb_unlock    = 0;
+
+  bool has_lock_been_found = false;
+
+  for (EventHandle e = wait_handle; e <= wait_handle; e--) {
+
+    if (exec->get_transition_for_handle(e)->type_ != Transition::Type::SEM_ASYNC_LOCK and
+        exec->get_transition_for_handle(e)->type_ != Transition::Type::SEM_UNLOCK)
+      continue;
+
+    // We ignore lock that have occured after the lock corresponding to the considered wait
+    if (not has_lock_been_found and exec->get_transition_for_handle(e)->type_ == Transition::Type::SEM_ASYNC_LOCK) {
+      if (exec->get_actor_with_handle(e) != exec->get_actor_with_handle(wait_handle))
+        continue;
+      else
+        has_lock_been_found = true;
+    }
+
+    auto sem_transition = static_cast<const SemaphoreTransition*>(exec->get_transition_for_handle(e));
+
+    if (sem_transition->get_sem() != sem_id)
+      continue;
+
+    max_capacity = sem_transition->get_capacity();
+    max_capacity += sem_transition->type_ == Transition::Type::SEM_ASYNC_LOCK ? 1 : -1;
+
+    if (e == unlock_handle)
+      continue;
+
+    if (sem_transition->type_ == Transition::Type::SEM_ASYNC_LOCK)
+      nb_lock++;
+    if (sem_transition->type_ == Transition::Type::SEM_UNLOCK)
+      nb_unlock++;
   }
 
+  XBT_DEBUG("Conclusion is the following:\n\t[Max_capacity = %d]\n\t[nb_lock = %d]\n\t[nb_unlock = %d]", max_capacity,
+            nb_lock, nb_unlock);
+  XBT_DEBUG("Hence, the wait is %s without the unlock",
+            max_capacity - nb_lock + nb_unlock >= 0 ? "fireable" : "not fireable");
+  return max_capacity - nb_lock + nb_unlock >= 0;
+}
+
+bool SemaphoreTransition::reversible_race(const Transition* other, const odpor::Execution* exec,
+                                          EventHandle this_handle, EventHandle other_handle) const
+{
   if (other->type_ == Type::ACTOR_JOIN) {
     const ActorJoinTransition* jtransition = static_cast<const ActorJoinTransition*>(other);
     xbt_assert(aid_ == jtransition->get_target());
     return false;
   }
 
-  switch (type_) {
+  switch (other->type_) {
     case Type::SEM_ASYNC_LOCK:
       return true; // SemAsyncLock is always enabled
     case Type::SEM_UNLOCK:
       return true; // SemUnlock is always enabled
     case Type::SEM_WAIT:
-      // Some times the race is not reversible: we decide to catch it during the exploration
-      // instead of doing tedious computation here.
-      return true;
+      xbt_assert(this->type_ == Type::SEM_UNLOCK);
+      // Some times the race is not reversible
+      return is_sem_wait_fireable_without_unlock(exec, this_handle, other_handle);
     default:
       xbt_die("Unexpected transition type %s", to_c_str(type_));
   }
@@ -212,9 +264,9 @@ bool SemaphoreTransition::reversible_race(const Transition* other) const
 std::string SemaphoreTransition::to_string(bool verbose) const
 {
   if (type_ == Type::SEM_ASYNC_LOCK || type_ == Type::SEM_UNLOCK)
-    return xbt::string_printf("%s(semaphore: %u, capacity: %u)", Transition::to_c_str(type_), sem_, capacity_);
+    return xbt::string_printf("%s(semaphore: %u, capacity: %d)", Transition::to_c_str(type_), sem_, capacity_);
   if (type_ == Type::SEM_WAIT)
-    return xbt::string_printf("%s(semaphore: %u, capacity: %u, granted: %s)", Transition::to_c_str(type_), sem_,
+    return xbt::string_printf("%s(semaphore: %u, capacity: %d, granted: %s)", Transition::to_c_str(type_), sem_,
                               capacity_, granted_ ? "yes" : "no");
   THROW_IMPOSSIBLE;
 }
@@ -223,7 +275,7 @@ SemaphoreTransition::SemaphoreTransition(aid_t issuer, int times_considered, Typ
 {
   sem_      = channel.unpack<unsigned>();
   granted_  = channel.unpack<bool>();
-  capacity_ = channel.unpack<unsigned>();
+  capacity_ = channel.unpack<int>();
 }
 bool SemaphoreTransition::depends(const Transition* o) const
 {
@@ -261,15 +313,16 @@ bool SemaphoreTransition::depends(const Transition* o) const
   return false; // semaphores are INDEP with non-semaphore transitions
 }
 
-bool MutexTransition::reversible_race(const Transition* other) const
+bool MutexTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                      EventHandle other_handle) const
 {
-  if (other->type_ == Type::ACTOR_CREATE) {
-    const ActorCreateTransition* ctransition = static_cast<const ActorCreateTransition*>(other);
-    xbt_assert(aid_ == ctransition->get_child());
+  if (other->type_ == Type::ACTOR_JOIN) {
+    const ActorJoinTransition* jtransition = static_cast<const ActorJoinTransition*>(other);
+    xbt_assert(aid_ == jtransition->get_target());
     return false;
   }
 
-  switch (type_) {
+  switch (other->type_) {
     case Type::MUTEX_ASYNC_LOCK:
       return true; // MutexAsyncLock is always enabled
     case Type::MUTEX_TEST:
@@ -339,11 +392,99 @@ bool CondvarTransition::depends(const Transition* o) const
   // Independent with transitions that are neither Condvar nor Mutex related
   return false;
 }
-bool CondvarTransition::reversible_race(const Transition* other) const
+
+static bool is_cv_wait_fireable_without_transition(const odpor::Execution* exec, EventHandle cv_wait_handle,
+                                                   EventHandle other_handle)
 {
-  if (other->type_ == Type::ACTOR_CREATE) {
-    const ActorCreateTransition* ctransition = static_cast<const ActorCreateTransition*>(other);
-    xbt_assert(aid_ == ctransition->get_child());
+  unsigned cv_id =
+      static_cast<const CondvarTransition*>(exec->get_transition_for_handle(cv_wait_handle))->get_condvar();
+  int signal_after_lock = 0;
+
+  EventHandle lock_handle = 0;
+
+  for (EventHandle e = cv_wait_handle - 1; e <= cv_wait_handle; e--) {
+
+    if (e == other_handle)
+      continue;
+
+    if (const auto type = exec->get_transition_for_handle(e)->type_; type != Transition::Type::CONDVAR_ASYNC_LOCK and
+                                                                     type != Transition::Type::CONDVAR_BROADCAST and
+                                                                     type != Transition::Type::CONDVAR_SIGNAL)
+      continue;
+
+    auto cv_transition = static_cast<const CondvarTransition*>(exec->get_transition_for_handle(e));
+
+    if (cv_transition->get_condvar() != cv_id)
+      continue;
+
+    if (cv_transition->aid_ == exec->get_actor_with_handle(cv_wait_handle)) {
+      xbt_assert(cv_transition->type_ == Transition::Type::CONDVAR_ASYNC_LOCK,
+                 "A condvar wait is always preceeded by an async_lock right? (aid: %ld)", cv_transition->aid_);
+      lock_handle = e;
+      break;
+    }
+
+    switch (cv_transition->type_) {
+      case Transition::Type::CONDVAR_ASYNC_LOCK:
+        break; // The other lock happening after the concerned one don't matter
+      case Transition::Type::CONDVAR_BROADCAST:
+        return true; // If there's still a broadcast after the asynclock and before the wait, the wait is fireable
+      case Transition::Type::CONDVAR_SIGNAL:
+        signal_after_lock++;
+        break;
+      default:
+        xbt_die("What? What is this kind of transition? (%s) Fix Me!", Transition::to_c_str(cv_transition->type_));
+    }
+  }
+
+  if (signal_after_lock == 0)
+    return false; // If no signal happened after the lock, the wait can't be enabled
+
+  // For the remaining cases, we have to find how many people are waiting on the cv before the lock is issued
+
+  xbt_assert(lock_handle > 0);
+  int currently_waiting_on_cv = 0;
+  for (EventHandle e = 0; e < lock_handle; e++) {
+
+    if (e == other_handle)
+      continue;
+
+    if (exec->get_transition_for_handle(e)->type_ != Transition::Type::CONDVAR_ASYNC_LOCK and
+        exec->get_transition_for_handle(e)->type_ != Transition::Type::CONDVAR_BROADCAST and
+        exec->get_transition_for_handle(e)->type_ != Transition::Type::CONDVAR_SIGNAL)
+      continue;
+
+    auto cv_transition = static_cast<const CondvarTransition*>(exec->get_transition_for_handle(e));
+
+    if (cv_transition->get_condvar() != cv_id)
+      continue;
+
+    switch (cv_transition->type_) {
+      case Transition::Type::CONDVAR_ASYNC_LOCK:
+        currently_waiting_on_cv++;
+        break;
+      case Transition::Type::CONDVAR_BROADCAST:
+        currently_waiting_on_cv = 0;
+        break;
+      case Transition::Type::CONDVAR_SIGNAL:
+        // If no one is currently waiting, the signal is lost
+        currently_waiting_on_cv = std::max(0, currently_waiting_on_cv - 1);
+        break;
+      default:
+        xbt_die("What? What is this kind of transition? (%s) Fix Me!", Transition::to_c_str(cv_transition->type_));
+    }
+  }
+
+  // For the wait to be enabled, we need to signal each actor currently waiting + the one we just put there
+  return signal_after_lock > currently_waiting_on_cv;
+}
+
+bool CondvarTransition::reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                                        EventHandle other_handle) const
+{
+  if (other->type_ == Type::ACTOR_JOIN) {
+    const ActorJoinTransition* jtransition = static_cast<const ActorJoinTransition*>(other);
+    xbt_assert(aid_ == jtransition->get_target());
     return false;
   }
 
@@ -360,14 +501,14 @@ bool CondvarTransition::reversible_race(const Transition* other) const
                   to_c_str(other->type_));
       }
 
-      // if wait can be executed in the first place, then broadcast and signal don't impact him
+      // broadcast and signal can enable the wait, hence this race is not always reversible
     case Type::CONDVAR_BROADCAST:
     case Type::CONDVAR_SIGNAL:
       xbt_assert(other->type_ == Transition::Type::CONDVAR_ASYNC_LOCK or
                  other->type_ == Transition::Type::CONDVAR_WAIT);
-      return true;
+      return is_cv_wait_fireable_without_transition(exec, other_handle, this_handle);
 
-      // broadcast and signal can enable the wait, hence this race is not always reversible
+      // if wait can be executed in the first place, then broadcast and signal don't impact it
     case Type::CONDVAR_WAIT:
       xbt_assert(other->type_ == Transition::Type::CONDVAR_BROADCAST or
                  other->type_ == Transition::Type::CONDVAR_SIGNAL);
