@@ -6,6 +6,7 @@
 #ifndef SIMGRID_MC_TRANSITION_SYNCHRO_HPP
 #define SIMGRID_MC_TRANSITION_SYNCHRO_HPP
 
+#include "src/mc/explo/odpor/Execution.hpp"
 #include "src/mc/remote/Channel.hpp"
 #include "src/mc/transition/Transition.hpp"
 
@@ -20,7 +21,8 @@ public:
   std::string to_string(bool verbose) const override;
   BarrierTransition(aid_t issuer, int times_considered, Type type, mc::Channel& channel);
   bool depends(const Transition* other) const override;
-  bool reversible_race(const Transition* other) const override;
+  bool reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                       EventHandle other_handle) const override;
 };
 
 class MutexTransition : public Transition {
@@ -32,7 +34,8 @@ public:
   MutexTransition(aid_t issuer, int times_considered, Type type, mc::Channel& channel);
   bool depends(const Transition* other) const override;
   bool can_be_co_enabled(const Transition* other) const override;
-  bool reversible_race(const Transition* other) const override;
+  bool reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                       EventHandle other_handle) const override;
 
   uintptr_t get_mutex() const { return this->mutex_; }
   aid_t get_owner() const { return this->owner_; }
@@ -41,13 +44,14 @@ public:
 class SemaphoreTransition : public Transition {
   unsigned int sem_; // ID
   bool granted_;
-  unsigned capacity_;
+  int capacity_;
 
 public:
   std::string to_string(bool verbose) const override;
   SemaphoreTransition(aid_t issuer, int times_considered, Type type, mc::Channel& channel);
   bool depends(const Transition* other) const override;
-  bool reversible_race(const Transition* other) const override;
+  bool reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                       EventHandle other_handle) const override;
 
   int get_capacity() const { return capacity_; }
   unsigned int get_sem() const { return sem_; }
@@ -64,7 +68,8 @@ public:
   CondvarTransition(aid_t issuer, int times_considered, Type type, mc::Channel& channel);
   bool depends(const Transition* other) const override;
   bool can_be_co_enabled(const Transition* other) const override;
-  bool reversible_race(const Transition* other) const override;
+  bool reversible_race(const Transition* other, const odpor::Execution* exec, EventHandle this_handle,
+                       EventHandle other_handle) const override;
 
   unsigned int get_condvar() const { return this->condvar_; }
   unsigned int get_mutex() const { return this->mutex_; }
