@@ -92,7 +92,7 @@ ActorPtr Actor::create(const std::string& name, s4u::Host* host, const std::func
 ActorPtr Actor::create(const std::string& name, s4u::Host* host, const std::string& function,
                        std::vector<std::string> args)
 {
-  return s4u::Engine::get_instance()->add_actor(name, host, function, std::move(args));
+  return host->add_actor(name, function, std::move(args));
 }
 
 void intrusive_ptr_add_ref(const Actor* actor)
@@ -389,11 +389,28 @@ void parallel_execute(const std::vector<s4u::Host*>& hosts, const std::vector<do
   exec_init(hosts, flops_amounts, bytes_amounts)->wait();
 }
 
+ExecPtr thread_execute_async(s4u::Host* host, double flops_amount, int thread_count)
+{
+  auto res = Exec::init()->set_flops_amount(flops_amount)->set_host(host)->set_thread_count(thread_count);
+  res->start();
+  return res;
+}
+
+ExecPtr thread_execute_async(double flops_amount, int thread_count)
+{
+  return thread_execute_async(get_host(), flops_amount, thread_count);
+}
+
 void thread_execute(s4u::Host* host, double flops_amount, int thread_count)
 {
   Exec::init()->set_flops_amount(flops_amount)->set_host(host)->set_thread_count(thread_count)->wait();
 }
 
+void thread_execute(double flops_amount, int thread_count)
+{
+  exec_init(flops_amount)->set_thread_count(thread_count)->wait();
+}
+
 ExecPtr exec_init(double flops_amount)
 {
   return Exec::init()->set_flops_amount(flops_amount)->set_host(get_host());
@@ -472,7 +489,9 @@ void suspend()
 void exit()
 {
   kernel::actor::ActorImpl* self = simgrid::kernel::actor::ActorImpl::self();
-  simgrid::kernel::actor::simcall_answered([self] { self->exit(); });
+  kernel::actor::ActorExitSimcall observer{self};
+
+  simgrid::kernel::actor::simcall_answered([self] { self->exit(); }, &observer);
   THROW_IMPOSSIBLE;
 }
 
