@@ -5,12 +5,6 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-
-#include <simgrid/kernel/routing/NetPoint.hpp>
-#include <simgrid/modelchecker.h>
-#include <simgrid/s4u/Engine.hpp>
-
-#include "simgrid/forward.h"
 #include "simgrid/kernel/routing/DijkstraZone.hpp"
 #include "simgrid/kernel/routing/EmptyZone.hpp"
 #include "simgrid/kernel/routing/FloydZone.hpp"
@@ -19,6 +13,7 @@
 #include "simgrid/kernel/routing/VivaldiZone.hpp"
 #include "simgrid/kernel/routing/WifiZone.hpp"
 #include "src/instr/instr_private.hpp"
+#include "src/internal_config.h"
 #include "src/kernel/EngineImpl.hpp"
 #include "src/kernel/actor/ActorImpl.hpp"
 #include "src/kernel/resource/HostImpl.hpp"
@@ -30,6 +25,9 @@
 #include "src/simgrid/module.hpp"
 #include "xbt/asserts.h"
 #include "xbt/config.hpp"
+#include <simgrid/kernel/routing/NetPoint.hpp>
+#include <simgrid/modelchecker.h>
+#include <simgrid/s4u/Engine.hpp>
 
 #if HAVE_PAPI
 #include "src/simgrid/sg_config.hpp"
@@ -50,7 +48,6 @@ static simgrid::kernel::actor::ActorCode maestro_code;
 namespace simgrid::s4u {
 xbt::signal<void()> Engine::on_platform_creation;
 xbt::signal<void()> Engine::on_platform_created;
-xbt::signal<void()> Engine::on_platform_sealed;
 xbt::signal<void()> Engine::on_simulation_start;
 xbt::signal<void()> Engine::on_simulation_end;
 xbt::signal<void(double)> Engine::on_time_advance;
@@ -253,25 +250,18 @@ const std::vector<simgrid::kernel::resource::Model*>& Engine::get_all_models() c
 {
   return pimpl_->get_all_models();
 }
-ActorPtr Engine::add_actor(const std::string& name, s4u::Host* host, const std::function<void()>& code)
-{
-  kernel::actor::ActorImpl* self = kernel::actor::ActorImpl::self();
-  kernel::actor::ActorCreateSimcall observer{self};
-  kernel::actor::ActorImpl* actor = kernel::actor::simcall_answered(
-      [self, &name, host, &code, &observer] {
-        auto child = self->init(name, host)->start(code);
-        observer.set_child(child->get_pid());
-        return child;
-      },
-      &observer);
 
-  return actor->get_iface();
+
+ActorPtr Engine::add_actor(const std::string& name, s4u::Host* host, const std::function<void()>& code) //XBT_ATTRIB_DEPRECATED_v403
+{
+  return host->add_actor(name, code);
 }
+
 ActorPtr Engine::add_actor(const std::string& name, s4u::Host* host, const std::string& function,
-                           std::vector<std::string> args)
+                           std::vector<std::string> args) //XBT_ATTRIB_DEPRECATED_v403
 {
   const simgrid::kernel::actor::ActorCodeFactory& factory = pimpl_->get_function(function);
-  return add_actor(name, host, factory(std::move(args)));
+  return host->add_actor(name, factory(std::move(args)));
 }
 
 void Engine::load_platform(const std::string& platf) const
@@ -657,6 +647,11 @@ std::vector<ActorPtr> Engine::get_all_actors() const
   return actor_list;
 }
 
+void Engine::display_all_actors_status() const
+{
+  pimpl_->display_all_actor_status();
+}
+
 std::vector<ActorPtr> Engine::get_filtered_actors(const std::function<bool(ActorPtr)>& filter) const
 {
   std::vector<ActorPtr> actor_list;
