@@ -1,4 +1,4 @@
-/* Copyright (c) 2018-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2018-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -15,6 +15,51 @@
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_io, s4u_activity, "S4U asynchronous I/Os");
 
 namespace simgrid::s4u {
+template <> xbt::signal<void(Io&)> Activity_T<Io>::on_veto             = xbt::signal<void(Io&)>();
+template <> xbt::signal<void(Io const&)> Activity_T<Io>::on_start      = xbt::signal<void(Io const&)>();
+template <> xbt::signal<void(Io const&)> Activity_T<Io>::on_completion = xbt::signal<void(Io const&)>();
+template <> xbt::signal<void(Io const&)> Activity_T<Io>::on_suspend    = xbt::signal<void(Io const&)>();
+template <> xbt::signal<void(Io const&)> Activity_T<Io>::on_resume     = xbt::signal<void(Io const&)>();
+template <> void Activity_T<Io>::fire_on_start() const
+{
+  on_start(static_cast<const Io&>(*this));
+}
+template <> void Activity_T<Io>::fire_on_completion() const
+{
+  on_completion(static_cast<const Io&>(*this));
+}
+template <> void Activity_T<Io>::fire_on_suspend() const
+{
+  on_suspend(static_cast<const Io&>(*this));
+}
+template <> void Activity_T<Io>::fire_on_resume() const
+{
+  on_resume(static_cast<const Io&>(*this));
+}
+template <> void Activity_T<Io>::fire_on_veto()
+{
+  on_veto(static_cast<Io&>(*this));
+}
+template <> void Activity_T<Io>::on_start_cb(const std::function<void(Io const&)>& cb)
+{
+  on_start.connect(cb);
+}
+template <> void Activity_T<Io>::on_completion_cb(const std::function<void(Io const&)>& cb)
+{
+  on_completion.connect(cb);
+}
+template <> void Activity_T<Io>::on_suspend_cb(const std::function<void(Io const&)>& cb)
+{
+  on_suspend.connect(cb);
+}
+template <> void Activity_T<Io>::on_resume_cb(const std::function<void(Io const&)>& cb)
+{
+  on_resume.connect(cb);
+}
+template <> void Activity_T<Io>::on_veto_cb(const std::function<void(Io&)>& cb)
+{
+  on_veto.connect(cb);
+}
 
 Io::Io(kernel::activity::IoImplPtr pimpl)
 {
@@ -37,7 +82,10 @@ IoPtr Io::streamto_init(Host* from, const Disk* from_disk, Host* to, const Disk*
 IoPtr Io::streamto_async(Host* from, const Disk* from_disk, Host* to, const Disk* to_disk,
                          uint64_t simulated_size_in_bytes)
 {
-  return Io::init()->set_size(simulated_size_in_bytes)->set_source(from, from_disk)->set_destination(to, to_disk);
+  auto io = Io::init()->set_size(simulated_size_in_bytes)->set_source(from, from_disk)->set_destination(to, to_disk);
+  if (simulated_size_in_bytes == 0) // a zero-size I/O stream is explicitely asked for, start it!
+    io->start();
+  return io;
 }
 
 void Io::streamto(Host* from, const Disk* from_disk, Host* to, const Disk* to_disk, uint64_t simulated_size_in_bytes)
@@ -83,8 +131,13 @@ IoPtr Io::set_destination(Host* to, const Disk* to_disk)
 
 Io* Io::do_start()
 {
-  kernel::actor::simcall_answered(
-      [this] { (*boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_)).set_name(get_name()).start(); });
+  kernel::actor::simcall_answered([this] {
+    auto pimpl = boost::static_pointer_cast<kernel::activity::IoImpl>(pimpl_);
+    pimpl->set_name(get_name());
+    if (detached_)
+      pimpl->detach();
+    pimpl->start();
+  });
 
   if (suspended_)
     pimpl_->suspend();
@@ -95,7 +148,7 @@ Io* Io::do_start()
   return this;
 }
 
-ssize_t Io::deprecated_wait_any_for(const std::vector<IoPtr>& ios, double timeout) // XBT_ATTRIB_DEPRECATED_v339
+ssize_t Io::deprecated_wait_any_for(const std::vector<IoPtr>& ios, double timeout) // XBT_ATTRIB_DEPRECATED_v401
 {
   ActivitySet set;
   for (const auto& io : ios)
