@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -8,6 +8,7 @@
 #include <simgrid/s4u/Mailbox.hpp>
 
 #include "src/kernel/activity/MailboxImpl.hpp"
+#include "src/kernel/actor/CommObserver.hpp"
 
 XBT_LOG_EXTERNAL_CATEGORY(s4u);
 XBT_LOG_NEW_DEFAULT_SUBCATEGORY(s4u_channel, s4u, "S4U Communication Mailboxes");
@@ -93,6 +94,8 @@ CommPtr Mailbox::put_init()
 
 CommPtr Mailbox::put_init(void* payload, uint64_t simulated_size_in_bytes)
 {
+  xbt_assert(payload != nullptr, "You cannot send nullptr");
+
   return put_init()->set_payload_size(simulated_size_in_bytes)->set_src_data(payload)->set_src_data_size(sizeof(void*));
 }
 
@@ -109,7 +112,14 @@ void Mailbox::put(void* payload, uint64_t simulated_size_in_bytes)
 {
   xbt_assert(payload != nullptr, "You cannot send nullptr");
 
-  put_init()->set_payload_size(simulated_size_in_bytes)->set_src_data(payload)->start()->wait();
+  CommPtr comm = put_init()->set_payload_size(simulated_size_in_bytes)->set_src_data(payload)->start();
+  try {
+    comm->wait();
+  } catch (simgrid::TimeoutException&) {
+    comm->cancel();
+    // Rethrowing the original exception segfaults in parallel tests
+    throw TimeoutException(XBT_THROW_POINT, "Timeouted");
+  }
 }
 
 /** Blocking send with timeout */
@@ -117,7 +127,7 @@ void Mailbox::put(void* payload, uint64_t simulated_size_in_bytes, double timeou
 {
   xbt_assert(payload != nullptr, "You cannot send nullptr");
 
-  put_init()->set_payload_size(simulated_size_in_bytes)->set_src_data(payload)->start()->wait_for(timeout);
+  put_init()->set_payload_size(simulated_size_in_bytes)->set_src_data(payload)->start()->wait_for_or_cancel(timeout);
 }
 
 CommPtr Mailbox::get_init()
@@ -135,10 +145,13 @@ CommPtr Mailbox::get_async()
 }
 
 kernel::activity::ActivityImplPtr
-Mailbox::iprobe(int type, const std::function<bool(void*, void*, kernel::activity::CommImpl*)>& match_fun, void* data)
+Mailbox::iprobe(IprobeKind kind, const std::function<bool(void*, void*, kernel::activity::CommImpl*)>& match_fun,
+                void* data)
 {
+  auto self = kernel::actor::ActorImpl::self();
+  kernel::actor::IprobeSimcall observer(self, pimpl_, kind, match_fun, data);
   return kernel::actor::simcall_answered(
-      [this, type, &match_fun, data] { return pimpl_->iprobe(type, match_fun, data); });
+      [this, kind, &match_fun, data] { return pimpl_->iprobe(kind, match_fun, data); }, &observer);
 }
 
 void Mailbox::clear()
