@@ -1,4 +1,4 @@
-/* Copyright (c) 2006-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2006-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -23,11 +23,18 @@ void Mutex::lock()
     auto acquisition =
         kernel::actor::simcall_answered([issuer, this] { return pimpl_->lock_async(issuer); }, &lock_observer);
 
-    kernel::actor::MutexObserver wait_observer{issuer, mc::Transition::Type::MUTEX_WAIT, pimpl_};
+    kernel::actor::MutexAcquisitionObserver wait_observer{issuer, mc::Transition::Type::MUTEX_WAIT, acquisition.get(),
+                                                          -1};
     kernel::actor::simcall_blocking([issuer, &acquisition] { acquisition->wait_for(issuer, -1); }, &wait_observer);
 
   } else { // Do it in one simcall only
-    kernel::actor::simcall_blocking([issuer, this] { pimpl_->lock_async(issuer)->wait_for(issuer, -1); });
+    // We don't need no observer on this non-MC path, but simcall_blocking() requires it.
+    // Use a type clearly indicating it's NO-MC in the hope to get a loud error if it gets used despite our
+    // expectations.
+    kernel::actor::MutexAcquisitionObserver useless_observer{issuer, mc::Transition::Type::MUTEX_LOCK_NOMC, nullptr,
+                                                             -1};
+    kernel::actor::simcall_blocking([issuer, this] { pimpl_->lock_async(issuer)->wait_for(issuer, -1); },
+                                    &useless_observer);
   }
 }
 
