@@ -27,12 +27,19 @@ namespace simgrid::s4u {
 
 xbt::signal<void(NetZone const&)> NetZone::on_creation;
 xbt::signal<void(NetZone const&)> NetZone::on_seal;
+xbt::signal<void(NetZone const&)> NetZone::on_unseal;
 
 const std::unordered_map<std::string, std::string>* NetZone::get_properties() const
 {
   return pimpl_->get_properties();
 }
 
+NetZone* NetZone::set_properties(const std::unordered_map<std::string, std::string>& properties)
+{
+  pimpl_->set_properties(properties);
+  return this;
+}
+
 /** Retrieve the property value (or nullptr if not set) */
 const char* NetZone::get_property(const std::string& key) const
 {
@@ -199,6 +206,11 @@ NetZone* NetZone::seal()
   kernel::actor::simcall_answered([this] { pimpl_->seal(); });
   return this;
 }
+NetZone* NetZone::unseal()
+{
+  kernel::actor::simcall_answered([this] { pimpl_->unseal(); });
+  return this;
+}
 void NetZone::set_latency_factor_cb(
     std::function<double(double size, const s4u::Host* src, const s4u::Host* dst,
                          const std::vector<s4u::Link*>& /*links*/,
