@@ -1,4 +1,4 @@
-/* Copyright (c) 2007-2023. The SimGrid Team. All rights reserved.          */
+/* Copyright (c) 2007-2025. The SimGrid Team. All rights reserved.          */
 
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
@@ -10,6 +10,7 @@
 #include "smpi/smpi_helpers_internal.h"
 #include "smpi_utils.hpp"
 #include "src/instr/instr_smpi.hpp"
+#include "xbt/base.h"
 #include <unordered_map>
 #include <vector>
 
@@ -82,10 +83,13 @@ XBT_PRIVATE void smpi_deployment_unregister_process(const std::string& instance_
 
 XBT_PRIVATE MPI_Comm* smpi_deployment_comm_world(const std::string& instance_id);
 XBT_PRIVATE void smpi_deployment_cleanup_instances();
-XBT_PRIVATE int smpi_deployment_smpirun(const simgrid::s4u::Engine* e, const std::string& hostfile, int np,
+XBT_PRIVATE int smpi_deployment_smpirun(simgrid::s4u::Engine* e, const std::string& hostfile, int np,
                                         const std::string& replayfile, int map,
                                         const std::vector<const char*>& run_args);
 
+/** SMPI_executable functions*/
+XBT_PRIVATE void SMPI_executable_init(const std::string& executable);
+
 /** @brief Cleanup user's callback structure. Avoid segfault while destroying process */
 XBT_PRIVATE void smpi_cleanup_op_cost_callback();
 
@@ -125,6 +129,7 @@ XBT_PRIVATE void smpi_destroy_global_memory_segments();
 XBT_PRIVATE void smpi_bench_destroy();
 XBT_PRIVATE void smpi_shared_destroy();
 XBT_PRIVATE double smpi_adjust_comp_speed();
+XBT_PRIVATE double smpi_autobench();
 
 // This helper class uses RAII to call smpi_bench_end() when an object is built, and have smpi_bench_begin() be called
 // automatically when going out of scope.
