@@ -254,11 +254,12 @@ void* smpi_shared_malloc_partial(size_t size, const size_t* shared_block_offsets
                              smpi_shared_malloc_bogusfile, 0);
       xbt_assert(res == pos,
                  "Could not map folded virtual memory (%s). Do you perhaps need to increase the "
-                 "size of the mapped file using --cfg=smpi/shared-malloc-blocksize:newvalue (default 1048576) ?"
+                 "size of the mapped file using --cfg=smpi/shared-malloc-blocksize:newvalue (default 1048576) ? "
                  "You can also try using the sysctl vm.max_map_count.\n"
-                 "Failing params: add:%p, len:%zu, prot:%d(=PROT_READ | PROT_WRITE), flags:%d, fd:%d, offset:0. ",
+                 "Failing params: add:%p, len:%zu, prot:%d(=PROT_READ | PROT_WRITE), flags:%d, fd:%d, offset:0.\n"
+                 "Failing because res:%p != pos:%p. Error: %s",
                  strerror(errno), pos, low_page_stop_offset - low_page_start_offset, PROT_READ | PROT_WRITE,
-                 mmap_base_flag, smpi_shared_malloc_bogusfile);
+                 mmap_base_flag, smpi_shared_malloc_bogusfile, res, pos, strerror(errno));
     }
     if(low_page_stop_offset <= stop_block_offset) {
       XBT_DEBUG("\t\tglobal shared allocation, mmap block stop");
