@@ -26,9 +26,13 @@ extern "C" {
 int sthread_main(int argc, char** argv, char** envp, int (*raw_main)(int, char**, char**));
 XBT_PUBLIC void sthread_enable(void);  // Start intercepting all pthread calls
 XBT_PUBLIC void sthread_disable(void); // Stop intercepting all pthread calls
+XBT_PUBLIC int sthread_is_enabled(void); // Returns whether sthread is currenctly active
+XBT_PUBLIC void sthread_do_initialize(); // Specify that sthread is initialized in memory
+XBT_PUBLIC int sthread_is_initialized(void); // Returns whether sthread was inithalized (probably through LD_PRELOADED)
 
 typedef unsigned long int sthread_t;
 int sthread_create(sthread_t* thread, const /*pthread_attr_t*/ void* attr, void* (*start_routine)(void*), void* arg);
+int sthread_detach(sthread_t thread);
 int sthread_join(sthread_t thread, void** retval);
 XBT_ATTRIB_NORETURN void sthread_exit(void* retval);
 
@@ -100,6 +104,19 @@ void sthread_access_end(void* objaddr, const char* objname, const char* file, in
 
 #if defined(__cplusplus)
 }
+
+/* Puts sthread on a pause as long as this object is alive */
+class sthread_pause_guard {
+  int previous_state_;
+
+public:
+  sthread_pause_guard() : previous_state_(sthread_is_enabled()) { sthread_disable(); }
+  ~sthread_pause_guard()
+  {
+    if (previous_state_)
+      sthread_enable();
+  }
+};
 #endif
 
 #endif
