@@ -69,12 +69,12 @@ int main(int argc, char* argv[])
 #endif
 
   e.load_platform(argv[1]);
-  e.add_actor("receiver", e.host_by_name("Jupiter"), receiver, "box");
-  e.add_actor("sender", e.host_by_name("Boivin"), sender, "box", mutex, 1);
-  e.add_actor("sender", e.host_by_name("Fafard"), sender, "box", mutex, 2);
+  e.host_by_name("Jupiter")->add_actor("receiver", receiver, "box");
+  e.host_by_name("Boivin")->add_actor("sender", sender, "box", mutex, 1);
+  e.host_by_name("Fafard")->add_actor("sender", sender, "box", mutex, 2);
 
   e.run();
-  XBT_INFO("Simulation time %g", simgrid::s4u::Engine::get_clock());
+  XBT_INFO("Simulation time %g", e.get_clock());
 
   return 0;
 }
