@@ -4,6 +4,7 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "teshsuite/catch_simgrid.hpp"
+namespace sg4 = simgrid::s4u;
 
 TEST_CASE("Activity lifecycle: exec activities")
 {
@@ -14,13 +15,13 @@ TEST_CASE("Activity lifecycle: exec activities")
     XBT_INFO("Launch an execute(5s), and let it proceed");
     bool global = false;
 
-    simgrid::s4u::ActorPtr exec5 = simgrid::s4u::Engine::get_instance()->add_actor("exec5", all_hosts[1], [&global]() {
+    sg4::ActorPtr exec5 = all_hosts[1]->add_actor("exec5", [&global]() {
       assert_exit(true, 5.);
-      simgrid::s4u::this_actor::execute(500000000);
+      sg4::this_actor::execute(500000000);
       global = true;
     });
 
-    simgrid::s4u::this_actor::sleep_for(9);
+    sg4::this_actor::sleep_for(9);
     INFO("Did the forked actor modify the global after sleeping, or was it killed before?");
     REQUIRE(global);
 
@@ -30,13 +31,13 @@ TEST_CASE("Activity lifecycle: exec activities")
   BEGIN_SECTION("exec killed at start")
   {
     XBT_INFO("Launch an execute(5s), and kill it right after start");
-    simgrid::s4u::ActorPtr exec5 = simgrid::s4u::Engine::get_instance()->add_actor("exec5_killed", all_hosts[1], []() {
+    sg4::ActorPtr exec5 = all_hosts[1]->add_actor("exec5_killed", []() {
       assert_exit(false, 0);
-      simgrid::s4u::this_actor::execute(500000000);
+      sg4::this_actor::execute(500000000);
       FAIL("I should be dead now");
     });
 
-    simgrid::s4u::this_actor::yield();
+    sg4::this_actor::yield();
     exec5->kill();
 
     END_SECTION;
@@ -45,13 +46,13 @@ TEST_CASE("Activity lifecycle: exec activities")
   BEGIN_SECTION("exec killed in middle")
   {
     XBT_INFO("Launch an execute(5s), and kill it after 2 secs");
-    simgrid::s4u::ActorPtr exec5 = simgrid::s4u::Engine::get_instance()->add_actor("exec5_killed", all_hosts[1], []() {
+    sg4::ActorPtr exec5 = all_hosts[1]->add_actor("exec5_killed", []() {
       assert_exit(false, 2);
-      simgrid::s4u::this_actor::execute(500000000);
+      sg4::this_actor::execute(500000000);
       FAIL("I should be dead now");
     });
 
-    simgrid::s4u::this_actor::sleep_for(2);
+    sg4::this_actor::sleep_for(2);
     exec5->kill();
 
     END_SECTION;
@@ -60,14 +61,13 @@ TEST_CASE("Activity lifecycle: exec activities")
   BEGIN_SECTION("exec restarted at start")
   {
     XBT_INFO("Launch an execute(5s), and restart its host right after start");
-    simgrid::s4u::ActorPtr exec5 =
-        simgrid::s4u::Engine::get_instance()->add_actor("exec5_restarted", all_hosts[1], []() {
+    sg4::ActorPtr exec5 = all_hosts[1]->add_actor("exec5_restarted", []() {
           assert_exit(false, 0);
-          simgrid::s4u::this_actor::execute(500000000);
+          sg4::this_actor::execute(500000000);
           FAIL("I should be dead now");
         });
 
-    simgrid::s4u::this_actor::yield();
+    sg4::this_actor::yield();
     exec5->get_host()->turn_off();
     exec5->get_host()->turn_on();
 
@@ -77,14 +77,13 @@ TEST_CASE("Activity lifecycle: exec activities")
   BEGIN_SECTION("exec restarted in middle")
   {
     XBT_INFO("Launch an execute(5s), and restart its host after 2 secs");
-    simgrid::s4u::ActorPtr exec5 =
-        simgrid::s4u::Engine::get_instance()->add_actor("exec5_restarted", all_hosts[1], []() {
+    sg4::ActorPtr exec5 = all_hosts[1]->add_actor("exec5_restarted", []() {
           assert_exit(false, 2);
-          simgrid::s4u::this_actor::execute(500000000);
+          sg4::this_actor::execute(500000000);
           FAIL("I should be dead now");
         });
 
-    simgrid::s4u::this_actor::sleep_for(2);
+    sg4::this_actor::sleep_for(2);
     exec5->get_host()->turn_off();
     exec5->get_host()->turn_on();
 
@@ -96,26 +95,26 @@ TEST_CASE("Activity lifecycle: exec activities")
     XBT_INFO("Launch an execute(5s), and restart its host right when it stops");
     bool execution_done = false;
 
-    simgrid::s4u::Engine::get_instance()->add_actor("exec5_restarted", all_hosts[1], [&execution_done]() {
+    all_hosts[1]->add_actor("exec5_restarted", [&execution_done]() {
       assert_exit(true, 5);
-      simgrid::s4u::this_actor::execute(500000000);
+      sg4::this_actor::execute(500000000);
       execution_done = true;
     });
 
-    simgrid::s4u::Engine::get_instance()->add_actor("killer", all_hosts[0], []() {
-      simgrid::s4u::this_actor::sleep_for(5);
+    all_hosts[0]->add_actor("killer", []() {
+      sg4::this_actor::sleep_for(5);
       XBT_VERB("Killer!");
       all_hosts[1]->turn_off();
       all_hosts[1]->turn_on();
     });
 
-    simgrid::s4u::this_actor::sleep_for(9);
+    sg4::this_actor::sleep_for(9);
     INFO("Was restarted actor already dead in the scheduling round during which the host_off simcall was issued?");
     REQUIRE(execution_done);
 
     END_SECTION;
   }
 
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
   assert_cleanup();
 }
