@@ -4,6 +4,7 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "teshsuite/catch_simgrid.hpp"
+namespace sg4 = simgrid::s4u;
 
 TEST_CASE("Activity lifecycle: sleep activities")
 {
@@ -14,14 +15,13 @@ TEST_CASE("Activity lifecycle: sleep activities")
     XBT_INFO("Launch a sleep(5), and let it proceed");
     bool global = false;
 
-    simgrid::s4u::ActorPtr sleeper5 =
-        simgrid::s4u::Engine::get_instance()->add_actor("sleep5", all_hosts[1], [&global]() {
+    sg4::ActorPtr sleeper5 = all_hosts[1]->add_actor("sleep5", [&global]() {
           assert_exit(true, 5);
-          simgrid::s4u::this_actor::sleep_for(5);
+          sg4::this_actor::sleep_for(5);
           global = true;
         });
 
-    simgrid::s4u::this_actor::sleep_for(9);
+    sg4::this_actor::sleep_for(9);
     INFO("Did the forked actor modify the global after sleeping, or was it killed before?");
     REQUIRE(global);
 
@@ -31,14 +31,13 @@ TEST_CASE("Activity lifecycle: sleep activities")
   BEGIN_SECTION("sleep killed at start")
   {
     XBT_INFO("Launch a sleep(5), and kill it right after start");
-    simgrid::s4u::ActorPtr sleeper5 =
-        simgrid::s4u::Engine::get_instance()->add_actor("sleep5_killed", all_hosts[1], []() {
+    sg4::ActorPtr sleeper5 = all_hosts[1]->add_actor("sleep5_killed", []() {
           assert_exit(false, 0);
-          simgrid::s4u::this_actor::sleep_for(5);
+          sg4::this_actor::sleep_for(5);
           FAIL("I should be dead now");
         });
 
-    simgrid::s4u::this_actor::yield();
+    sg4::this_actor::yield();
     sleeper5->kill();
 
     END_SECTION;
@@ -47,14 +46,13 @@ TEST_CASE("Activity lifecycle: sleep activities")
   BEGIN_SECTION("sleep killed in middle")
   {
     XBT_INFO("Launch a sleep(5), and kill it after 2 secs");
-    simgrid::s4u::ActorPtr sleeper5 =
-        simgrid::s4u::Engine::get_instance()->add_actor("sleep5_killed", all_hosts[1], []() {
+    sg4::ActorPtr sleeper5 = all_hosts[1]->add_actor("sleep5_killed", []() {
           assert_exit(false, 2);
-          simgrid::s4u::this_actor::sleep_for(5);
+          sg4::this_actor::sleep_for(5);
           FAIL("I should be dead now");
         });
 
-    simgrid::s4u::this_actor::sleep_for(2);
+    sg4::this_actor::sleep_for(2);
     sleeper5->kill();
 
     END_SECTION;
@@ -66,14 +64,13 @@ TEST_CASE("Activity lifecycle: sleep activities")
   BEGIN_SECTION("sleep restarted at start")
   {
     XBT_INFO("Launch a sleep(5), and restart its host right after start");
-    simgrid::s4u::ActorPtr sleeper5 =
-        simgrid::s4u::Engine::get_instance()->add_actor("sleep5_restarted", all_hosts[1], []() {
+    sg4::ActorPtr sleeper5 = all_hosts[1]->add_actor("sleep5_restarted", []() {
           assert_exit(false, 0);
-          simgrid::s4u::this_actor::sleep_for(5);
+          sg4::this_actor::sleep_for(5);
           FAIL("I should be dead now");
         });
 
-    simgrid::s4u::this_actor::yield();
+    sg4::this_actor::yield();
     sleeper5->get_host()->turn_off();
     sleeper5->get_host()->turn_on();
 
@@ -83,14 +80,13 @@ TEST_CASE("Activity lifecycle: sleep activities")
   BEGIN_SECTION("sleep restarted in middle")
   {
     XBT_INFO("Launch a sleep(5), and restart its host after 2 secs");
-    simgrid::s4u::ActorPtr sleeper5 =
-        simgrid::s4u::Engine::get_instance()->add_actor("sleep5_restarted", all_hosts[1], []() {
+    sg4::ActorPtr sleeper5 = all_hosts[1]->add_actor("sleep5_restarted", []() {
           assert_exit(false, 2);
-          simgrid::s4u::this_actor::sleep_for(5);
+          sg4::this_actor::sleep_for(5);
           FAIL("I should be dead now");
         });
 
-    simgrid::s4u::this_actor::sleep_for(2);
+    sg4::this_actor::sleep_for(2);
     sleeper5->get_host()->turn_off();
     sleeper5->get_host()->turn_on();
 
@@ -102,20 +98,20 @@ TEST_CASE("Activity lifecycle: sleep activities")
     XBT_INFO("Launch a sleep(5), and restart its host right when it stops");
     bool sleeper_done = false;
 
-    simgrid::s4u::Engine::get_instance()->add_actor("sleep5_restarted", all_hosts[1], [&sleeper_done]() {
+    all_hosts[1]->add_actor("sleep5_restarted", [&sleeper_done]() {
       assert_exit(true, 5);
-      simgrid::s4u::this_actor::sleep_for(5);
+      sg4::this_actor::sleep_for(5);
       sleeper_done = true;
     });
 
-    simgrid::s4u::Engine::get_instance()->add_actor("killer", all_hosts[0], []() {
-      simgrid::s4u::this_actor::sleep_for(5);
+    all_hosts[0]->add_actor("killer", []() {
+      sg4::this_actor::sleep_for(5);
       XBT_VERB("Killer!");
       all_hosts[1]->turn_off();
       all_hosts[1]->turn_on();
     });
 
-    simgrid::s4u::this_actor::sleep_for(9);
+    sg4::this_actor::sleep_for(9);
     INFO("Was restarted actor already dead in the scheduling round during which the host_off simcall was issued?");
     REQUIRE(sleeper_done);
 
@@ -125,19 +121,19 @@ TEST_CASE("Activity lifecycle: sleep activities")
   BEGIN_SECTION("turn off its own host")
   {
     XBT_INFO("Launch a sleep(5), then saw off the branch it's sitting on");
-    simgrid::s4u::Engine::get_instance()->add_actor("sleep5_restarted", all_hosts[1], []() {
+    all_hosts[1]->add_actor("sleep5_restarted", []() {
       assert_exit(false, 5);
-      simgrid::s4u::this_actor::sleep_for(5);
-      simgrid::s4u::this_actor::get_host()->turn_off();
+      sg4::this_actor::sleep_for(5);
+      sg4::this_actor::get_host()->turn_off();
       FAIL("I should be dead now");
     });
 
-    simgrid::s4u::this_actor::sleep_for(9);
+    sg4::this_actor::sleep_for(9);
     all_hosts[1]->turn_on();
 
     END_SECTION;
   }
 
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
   assert_cleanup();
 }
