@@ -4,16 +4,17 @@
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
 #include "teshsuite/catch_simgrid.hpp"
+namespace sg4 = simgrid::s4u;
 
 //========== Creators: create an async activity
 
 template <typename Activity> using creator_type = Activity (*)(double);
 
 // Create a new async execution with given duration
-static simgrid::s4u::ExecPtr create_exec(double duration)
+static sg4::ExecPtr create_exec(double duration)
 {
-  double speed = simgrid::s4u::this_actor::get_host()->get_speed();
-  return simgrid::s4u::this_actor::exec_async(speed * duration);
+  double speed = sg4::this_actor::get_host()->get_speed();
+  return sg4::this_actor::exec_async(speed * duration);
 }
 
 // TODO: check other kinds of activities too (Io, Comm, ...)
@@ -32,7 +33,7 @@ template <typename Activity> bool tester_test(const Activity& activity)
 template <int Duration, typename Activity> bool tester_wait(const Activity& activity)
 {
   constexpr double duration = Duration / 128.0;
-  const double timeout      = simgrid::s4u::Engine::get_clock() + duration;
+  const double timeout      = sg4::Engine::get_clock() + duration;
   bool ret;
   try {
     XBT_DEBUG("calling wait_for(%f)", duration);
@@ -42,14 +43,14 @@ template <int Duration, typename Activity> bool tester_wait(const Activity& acti
   } catch (const simgrid::TimeoutException& e) {
     XBT_DEBUG("wait_for() timed out (%s)", e.what());
     INFO("wait_for() timeout should expire at expected date: " + std::to_string(timeout));
-    REQUIRE(simgrid::s4u::Engine::get_clock() == Approx(timeout));
+    REQUIRE(sg4::Engine::get_clock() == Approx(timeout));
     ret = false;
   } catch (const simgrid::Exception& e) {
     XBT_DEBUG("wait_for() threw an exception: %s", e.what());
     ret = true;
   }
   INFO("wait_for() should return before timeout expiration at date: " << timeout);
-  REQUIRE(simgrid::s4u::Engine::get_clock() <= Approx(timeout));
+  REQUIRE(sg4::Engine::get_clock() <= Approx(timeout));
   return ret;
 }
 
@@ -57,10 +58,10 @@ template <int Duration, typename Activity> bool tester_wait(const Activity& acti
 template <int Duration, typename Activity> bool tester_wait_any(const Activity& activity)
 {
   constexpr double duration = Duration / 128.0;
-  const double timeout      = simgrid::s4u::Engine::get_clock() + duration;
+  const double timeout      = sg4::Engine::get_clock() + duration;
   bool ret;
   try {
-    simgrid::s4u::ActivitySet set;
+    sg4::ActivitySet set;
     set.push(activity);
 
     XBT_DEBUG("calling wait_any_for(%f)", duration);
@@ -73,14 +74,14 @@ template <int Duration, typename Activity> bool tester_wait_any(const Activity&
   } catch (const simgrid::TimeoutException& e) {
     XBT_DEBUG("wait_any_for() timed out");
     INFO("wait_any_for() timeout should expire at expected date: " << timeout);
-    REQUIRE(simgrid::s4u::Engine::get_clock() == Approx(timeout));
+    REQUIRE(sg4::Engine::get_clock() == Approx(timeout));
     ret = false;
   } catch (const simgrid::Exception& e) {
     XBT_DEBUG("wait_any_for() threw an exception: %s", e.what());
     ret = true;
   }
   INFO("wait_any_for() should return before timeout expiration at date: " << timeout);
-  REQUIRE(simgrid::s4u::Engine::get_clock() <= Approx(timeout));
+  REQUIRE(sg4::Engine::get_clock() <= Approx(timeout));
   return ret;
 }
 
@@ -91,7 +92,7 @@ template <typename Activity> using waiter_type = void (*)(const Activity&);
 // Wait for 6s
 template <typename Activity> void waiter_sleep6(const Activity&)
 {
-  simgrid::s4u::this_actor::sleep_for(6.0);
+  sg4::this_actor::sleep_for(6.0);
   XBT_DEBUG("wake up after 6s sleep");
 }
 
@@ -108,10 +109,10 @@ template <typename Activity, creator_type<Activity> Create, tester_type<Activity
 {
   XBT_INFO("Launch an activity for 5s, and let it proceed before test");
 
-  simgrid::s4u::ActorPtr actor = simgrid::s4u::Engine::get_instance()->add_actor("actor", all_hosts[1], []() {
+  sg4::ActorPtr actor = all_hosts[1]->add_actor("actor", []() {
     assert_exit(true, 6.);
     Activity activity = Create(5.0);
-    simgrid::s4u::this_actor::sleep_for(6.0);
+    sg4::this_actor::sleep_for(6.0);
     INFO("activity should be terminated now");
     REQUIRE(Test(activity));
   });
@@ -122,14 +123,14 @@ template <typename Activity, creator_type<Activity> Create, tester_type<Activity
 {
   XBT_INFO("Launch an activity for 5s, and test while it proceeds");
 
-  simgrid::s4u::ActorPtr actor = simgrid::s4u::Engine::get_instance()->add_actor("actor", all_hosts[1], []() {
+  sg4::ActorPtr actor = all_hosts[1]->add_actor("actor", []() {
     assert_exit(true, 6.);
     Activity activity = Create(5.0);
     for (int i = 0; i < 3; i++) {
-      const double timestep = simgrid::s4u::Engine::get_clock() + 2.0;
+      const double timestep = sg4::Engine::get_clock() + 2.0;
       INFO("activity should be still running (i = " << i << ")");
       REQUIRE(not Test(activity));
-      simgrid::s4u::this_actor::sleep_until(timestep);
+      sg4::this_actor::sleep_until(timestep);
     }
     INFO("activity should be terminated now");
     REQUIRE(Test(activity));
@@ -141,10 +142,10 @@ template <typename Activity, creator_type<Activity> Create, tester_type<Activity
 {
   XBT_INFO("Launch an activity for 5s, and cancel it after 2s");
 
-  simgrid::s4u::ActorPtr actor = simgrid::s4u::Engine::get_instance()->add_actor("actor", all_hosts[1], []() {
+  sg4::ActorPtr actor = all_hosts[1]->add_actor("actor", []() {
     assert_exit(true, 2.);
     Activity activity = Create(5.0);
-    simgrid::s4u::this_actor::sleep_for(2.0);
+    sg4::this_actor::sleep_for(2.0);
     activity->cancel();
     INFO("activity should be terminated now");
     REQUIRE(Test(activity));
@@ -158,17 +159,17 @@ void test_failure_actor()
   XBT_INFO("Launch an activity for 5s, and kill running actor after 2s");
 
   Activity activity;
-  simgrid::s4u::ActorPtr actor = simgrid::s4u::Engine::get_instance()->add_actor("actor", all_hosts[1], [&activity]() {
+  sg4::ActorPtr actor = all_hosts[1]->add_actor("actor", [&activity]() {
     assert_exit(false, 2.);
     activity = Create(5.0);
     Wait(activity);
     FAIL("should not be here!");
   });
-  const double timestep = simgrid::s4u::Engine::get_clock() + 2.0;
-  simgrid::s4u::this_actor::sleep_for(1.0);
+  const double timestep = sg4::Engine::get_clock() + 2.0;
+  sg4::this_actor::sleep_for(1.0);
   INFO("activity should be still running");
   REQUIRE(not Test(activity));
-  simgrid::s4u::this_actor::sleep_until(timestep);
+  sg4::this_actor::sleep_until(timestep);
   actor->kill();
   INFO("activity should be terminated now");
   REQUIRE(Test(activity));
@@ -180,17 +181,17 @@ void test_failure_host()
   XBT_INFO("Launch an activity for 5s, and shutdown host 2s");
 
   Activity activity;
-  simgrid::s4u::ActorPtr actor = simgrid::s4u::Engine::get_instance()->add_actor("actor", all_hosts[1], [&activity]() {
+  sg4::ActorPtr actor = all_hosts[1]->add_actor("actor", [&activity]() {
     assert_exit(false, 2.);
     activity = Create(5.0);
     Wait(activity);
     FAIL("should not be here!");
   });
-  const double timestep = simgrid::s4u::Engine::get_clock() + 2.0;
-  simgrid::s4u::this_actor::sleep_for(1.0);
+  const double timestep = sg4::Engine::get_clock() + 2.0;
+  sg4::this_actor::sleep_for(1.0);
   INFO("activity should be still running");
   REQUIRE(not Test(activity));
-  simgrid::s4u::this_actor::sleep_until(timestep);
+  sg4::this_actor::sleep_until(timestep);
   actor->get_host()->turn_off();
   actor->get_host()->turn_on();
   INFO("activity should be terminated now");
@@ -199,7 +200,7 @@ void test_failure_host()
 
 //==========
 
-using simgrid::s4u::ExecPtr;
+using sg4::ExecPtr;
 
 TEST_CASE("Activity test/wait: using <tester_test>")
 {
@@ -217,7 +218,7 @@ TEST_CASE("Activity test/wait: using <tester_test>")
   RUN_SECTION("exec: host failure and test / wait",
               test_failure_host<ExecPtr, create_exec, tester_test, waiter_wait>);
 
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
   assert_cleanup();
 }
 
@@ -237,7 +238,7 @@ TEST_CASE("Activity test/wait: using <tester_wait<0>>")
   RUN_SECTION("exec: host failure and wait<0> / wait",
               test_failure_host<ExecPtr, create_exec, tester_wait<0>, waiter_wait>);
 
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
   assert_cleanup();
 }
 
@@ -257,7 +258,7 @@ TEST_CASE("Activity test/wait: using <tester_wait<1>>")
   RUN_SECTION("exec: host failure and wait<1> / wait",
               test_failure_host<ExecPtr, create_exec, tester_wait<1>, waiter_wait>);
 
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
   assert_cleanup();
 }
 
@@ -277,7 +278,7 @@ TEST_CASE("Activity test/wait: using <tester_wait_any<0>>")
   RUN_SECTION("exec: host failure and wait_any<0> / wait",
               test_failure_host<ExecPtr, create_exec, tester_wait_any<0>, waiter_wait>);
 
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
   assert_cleanup();
 }
 
@@ -297,6 +298,6 @@ TEST_CASE("Activity test/wait: using <tester_wait_any<1>>")
   RUN_SECTION("exec: host failure and wait_any<1> / wait",
               test_failure_host<ExecPtr, create_exec, tester_wait_any<1>, waiter_wait>);
 
-  simgrid::s4u::this_actor::sleep_for(10);
+  sg4::this_actor::sleep_for(10);
   assert_cleanup();
 }
