@@ -63,13 +63,13 @@ static void test_launcher(int test_number)
       // Create a process running a simple task on a host and turn the host off during the execution of the actor.
       XBT_INFO("Test 1:");
       XBT_INFO("  Create an actor on Jupiter");
-      e.add_actor("actor_daemon", jupiter, actor_daemon, std::ref(tasks_done));
+      jupiter->add_actor("actor_daemon", actor_daemon, std::ref(tasks_done));
       simgrid::s4u::this_actor::sleep_for(3);
       XBT_INFO("  Turn off Jupiter");
       jupiter->turn_off();
       simgrid::s4u::this_actor::sleep_for(10);
       XBT_INFO("Test 1 seems ok, cool !(#Actors: %zu, it should be 1; #tasks: %d)",
-               simgrid::s4u::Engine::get_instance()->get_actor_count(), tasks_done);
+               e.get_actor_count(), tasks_done);
       break;
     case 2:
       // Create an actor on an host that is turned off (this is not allowed)
@@ -79,7 +79,7 @@ static void test_launcher(int test_number)
       // adsein: This can be one additional test, to check that you cannot shutdown twice a host
       jupiter->turn_off();
       try {
-        e.add_actor("actor_daemon", jupiter, actor_daemon, std::ref(tasks_done));
+        jupiter->add_actor("actor_daemon",actor_daemon, std::ref(tasks_done));
         simgrid::s4u::this_actor::sleep_for(10);
         XBT_INFO("  Test 2 does crash as it should. This message will not be displayed.");
       } catch (const simgrid::HostFailureException&) {
@@ -95,31 +95,31 @@ static void test_launcher(int test_number)
                "Jupiter and Tremblay and turn off Jupiter during the communication");
       jupiter->turn_on();
       simgrid::s4u::this_actor::sleep_for(10);
-      e.add_actor("commRX", simgrid::s4u::Host::by_name("Tremblay"), commRX);
-      e.add_actor("commTX", jupiter, commTX);
-      XBT_INFO("  number of actors: %zu", simgrid::s4u::Engine::get_instance()->get_actor_count());
+      simgrid::s4u::Host::by_name("Tremblay")->add_actor("commRX", commRX);
+      jupiter->add_actor("commTX", commTX);
+      XBT_INFO("  number of actors: %zu", e.get_actor_count());
       simgrid::s4u::this_actor::sleep_for(10);
       XBT_INFO("  Turn Jupiter off");
       jupiter->turn_off();
       simgrid::s4u::this_actor::sleep_for(1); // Allow some time to the other actors to die
       XBT_INFO("Test 4 is ok.  (number of actors : %zu, it should be 1 or 2 if RX has not been satisfied)."
                " An exception is raised when we turn off a node that has an actor sleeping",
-               simgrid::s4u::Engine::get_instance()->get_actor_count());
+               e.get_actor_count());
       break;
     case 5:
       XBT_INFO("Test 5 (turn off dest during a communication : Create an actor/task to make a communication between "
                "Tremblay and Jupiter and turn off Jupiter during the communication");
       jupiter->turn_on();
       simgrid::s4u::this_actor::sleep_for(10);
-      e.add_actor("commRX", jupiter, commRX);
-      e.add_actor("commTX", simgrid::s4u::Host::by_name("Tremblay"), commTX);
-      XBT_INFO("  number of actors: %zu", simgrid::s4u::Engine::get_instance()->get_actor_count());
+      jupiter->add_actor("commRX", commRX);
+      simgrid::s4u::Host::by_name("Tremblay")->add_actor("commTX", commTX);
+      XBT_INFO("  number of actors: %zu", e.get_actor_count());
       simgrid::s4u::this_actor::sleep_for(10);
       XBT_INFO("  Turn Jupiter off");
       jupiter->turn_off();
       simgrid::s4u::this_actor::sleep_for(1); // Allow some time to the other actors to die
       XBT_INFO("Test 5 seems ok (number of actors: %zu, it should be 2)",
-               simgrid::s4u::Engine::get_instance()->get_actor_count());
+               e.get_actor_count());
       break;
     case 6:
       XBT_INFO("Test 6: Turn on Jupiter, assign a VM on Jupiter, launch an actor inside the VM, and turn off the node");
@@ -128,8 +128,8 @@ static void test_launcher(int test_number)
       vm0 = jupiter->create_vm("vm0", 1);
       vm0->start();
 
-      daemon = e.add_actor("actor_daemon", vm0, actor_daemon, std::ref(tasks_done));
-      e.add_actor("actor_daemonJUPI", jupiter, actor_daemon, std::ref(tasks_done));
+      daemon = vm0->add_actor("actor_daemon", actor_daemon, std::ref(tasks_done));
+      jupiter->add_actor("actor_daemonJUPI", actor_daemon, std::ref(tasks_done));
 
       daemon->suspend();
       vm0->set_bound(90);
@@ -160,11 +160,11 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  e.add_actor("test_launcher", e.host_by_name("Tremblay"), test_launcher, std::stoi(argv[2]));
+  e.host_by_name("Tremblay")->add_actor("test_launcher", test_launcher, std::stoi(argv[2]));
 
   e.run();
 
-  XBT_INFO("Simulation time %g", simgrid::s4u::Engine::get_clock());
+  XBT_INFO("Simulation time %g", e.get_clock());
 
   return 0;
 }
