@@ -13,6 +13,7 @@ rm -f /tmp/cc*
 rm -f /tmp/simgrid-mc-*
 rm -f /tmp/*.so
 rm -f /tmp/*.so.*
+rm -f /tmp/simgrid-java*
 ls /tmp
 df -h
 echo "XXXX Let's go"
@@ -49,7 +50,7 @@ do_cleanup() {
   find "$WORKSPACE" -name "memcheck_test_*.memcheck" -exec rm {} \;
 }
 
-do_cleanup "$WORKSPACE/build" "$WORKSPACE/memcheck"
+do_cleanup "$WORKSPACE/build" "$WORKSPACE/memcheck" "$WORKSPACE/generatedJUnitFiles"
 
 NUMPROC="$(nproc)" || NUMPROC=1
 
