@@ -25,6 +25,12 @@ get_json(){
   sed -n 's/.* JSON library \.\+: \([^ ]*\) in .*/\1/p;T;q' ./consoleText
 }
 
+get_java(){
+  # Found Java: /usr/bin/java (found suitable version "17.0.13", minimum required is "1.8") found components: Runtime Development
+  # -- [Java] Version: 21.0.5; Compiler: /usr/bin/javac; Runtime: /usr/bin/java
+  sed -n 's/.* Java version: \([^;]*\).*/\1/p;T;q' ./consoleText
+}
+
 get_ns3(){
   sed -n 's/.*-- ns-3 found (v\(3[-.0-9a-z]\+\).*/\1/p;T;q' ./consoleText
 }
@@ -32,7 +38,10 @@ get_ns3(){
 get_python(){
   found=$(grep -c "Compile Python bindings .....: ON" ./consoleText)
   if [ "$found" != 0 ]; then
-    grep -m 1 "Found Python3" ./consoleText| sed "s/.*-- Found Python3.*found version \"\([a-zA-Z0-9\.]*\)\".*/\1/g"
+    grep --max-count=1 "Found Python3" ./consoleText| sed "s/.*-- Found Python3.*found version \"\([a-zA-Z0-9\.]*\)\".*/\1/g"
+    if grep "Found Python3" ./consoleText | grep -q- "NumPy" ; then
+      echo "numpy"
+    fi
   else
     echo ""
   fi
@@ -132,14 +141,15 @@ function sortTable(n, type) {
     <td class=matrix-header style=min-width:75px onclick='sortTable($((col=0)));'>Name of the Builder</td>
     <td class=matrix-header style=min-width:75px onclick='sortTable($((++col)));'>OS</td>
     <td class=matrix-header style=min-width:50px onclick='sortTable($((++col,0)));'>Debug</td>
-    <td class=matrix-header style=min-width:50px onclick='sortTable($((++col,0)));'>MC</td>
+    <td class=matrix-header style=min-width:50px onclick='sortTable($((++col,0)));'>Release</td>
     <td class=matrix-header style=min-width:75px onclick='sortTable($((++col)));'>Compiler</td>
-    <td class=matrix-header style=min-width:75px onclick="sortTable($((++col)),'version');">Boost</td>
-    <td class=matrix-header style=min-width:75px onclick="sortTable($((++col)),'version');">Cmake</td>
+    <td class=matrix-header style=min-width:50px onclick="sortTable($((++col)),'version');">Boost</td>
+    <td class=matrix-header style=min-width:50px onclick="sortTable($((++col)),'version');">Cmake</td>
     <td class=matrix-header style=min-width:50px onclick="sortTable($((++col)),'version');">Eigen3</td>
     <td class=matrix-header style=min-width:50px onclick="sortTable($((++col)),'version');">JSON</td>
     <td class=matrix-header style=min-width:50px onclick="sortTable($((++col)),'version');">ns-3</td>
     <td class=matrix-header style=min-width:50px onclick="sortTable($((++col)),'version');">Python</td>
+    <td class=matrix-header style=min-width:50px onclick="sortTable($((++col)),'version');">Java</td>
   </tr>
 EOF
 
@@ -154,7 +164,7 @@ for node in "${nodes[@]}"
 do
     wget --quiet --output-document=consoleText \
          ${BUILD_URL}/build_mode=Debug,node=${node}/consoleText \
-         ${BUILD_URL}/build_mode=ModelChecker,node=${node}/consoleText \
+         ${BUILD_URL}/build_mode=Release,node=${node}/consoleText \
          >/dev/null 2>&1
     if [ ! -f consoleText ]; then
       echo "file not existing for node ${node}"
@@ -167,6 +177,7 @@ do
     json=$(get_json)
     ns3=$(get_ns3)
     py=$(get_python)
+    java=$(get_java)
     os=$(grep -m 1 "OS Version" ./consoleText| sed "s/OS Version : \(.*\)/\1/g")
 
     color1=""
@@ -181,14 +192,14 @@ do
     rm status
     statusdebug="<a href=\"build_mode=Debug,node=${node}/\"><img src=\"https://ci.inria.fr/simgrid/job/SimGrid/build_mode=Debug,node=${node}/badge/icon?style=ball-24x24${color1}\"/>"
 
-    statusmc="<${icons[disabled]}>"
-    wget --quiet https://ci.inria.fr/simgrid/buildStatus/text?job=SimGrid%2Fbuild_mode%3DModelChecker%2Cnode%3D"${node}" -O status >/dev/null 2>&1
+    statusrelease="<${icons[disabled]}>"
+    wget --quiet https://ci.inria.fr/simgrid/buildStatus/text?job=SimGrid%2Fbuild_mode%3DRelease%2Cnode%3D"${node}" -O status >/dev/null 2>&1
     status=$(cat status)
     if [ "$status" ]; then
       if [ "$status" == "Success" ]; then
         color2="&color=green"
       fi
-      statusmc="<a href=\"build_mode=ModelChecker,node=${node}/\"><img src=\"https://ci.inria.fr/simgrid/job/SimGrid/build_mode=ModelChecker,node=${node}/badge/icon?style=ball-24x24${color2}\"/>"
+      statusrelease="<a href=\"build_mode=Release,node=${node}/\"><img src=\"https://ci.inria.fr/simgrid/job/SimGrid/build_mode=Release,node=${node}/badge/icon?style=ball-24x24${color2}\"/>"
     fi
     rm status
 
@@ -197,7 +208,7 @@ do
     <td class="matrix-leftcolumn">$node</td>
     <td class="matrix-cell" style="text-align:left">$os</td>
     <td class="matrix-cell" style="text-align:center">${statusdebug}</td>
-    <td class="matrix-cell" style="text-align:center">${statusmc}</td>
+    <td class="matrix-cell" style="text-align:center">${statusrelease}</td>
     <td class="matrix-cell" style="text-align:left">$compiler</td>
     <td class="matrix-cell" style="text-align:left">$boost</td>
     <td class="matrix-cell" style="text-align:left">$cmake</td>
@@ -205,6 +216,7 @@ do
     <td class="matrix-cell" style="text-align:center">$json</td>
     <td class="matrix-cell" style="text-align:left">$ns3</td>
     <td class="matrix-cell" style="text-align:left">$py</td>
+    <td class="matrix-cell" style="text-align:left">$java</td>
   </tr>
 EOF
     rm consoleText
