@@ -444,6 +444,7 @@ class Cmd:
         else:
             stdouta = stdout_data.split("\n")
             stdouta = self.remove_ignored_lines(stdouta)
+            self.output_pipe_stdout = self.remove_ignored_lines(self.output_pipe_stdout)
             while stdouta and stdouta[-1] == "":
                 del stdouta[-1]
             stdcpy = stdouta[:]
@@ -595,6 +596,8 @@ def main():
             re.compile(r"profiling:"),
             re.compile(r"Unable to clean temporary file C:"),
             re.compile(r".*Configuration change: Set 'contexts/"),
+            re.compile(r"Picked up JAVA_TOOL_OPTIONS: "),
+            re.compile(r"Picked up _JAVA_OPTIONS: "),
             re.compile(r".*Configuration change: Set 'smpi/tmpdir"),
             re.compile(r"==[0-9]+== ?WARNING: ASan doesn't fully support"),
             re.compile(r"==[0-9]+== ?WARNING: ASan is ignoring requested __asan_handle_no_return: stack "),
